@@ -39,51 +39,141 @@ void print_tree(CSOUND *, char *, TREE *);
 /*     return a; */
 /* } */
 
+static TREE * create_fun_token(CSOUND *csound, TREE *right, char *fname)
+{
+    TREE *ans;
+    ans = (TREE*)mmalloc(csound, sizeof(TREE));
+    if (UNLIKELY(ans == NULL)) exit(1);
+    ans->type = T_FUNCTION;
+    ans->value = make_token(csound, fname);
+    ans->value->type = T_FUNCTION;
+    ans->left = NULL;
+    ans->right = right;
+    ans->next = NULL;
+    ans->len = 0;
+    ans->rate = -1;
+    return ans;
+}
+
+static TREE * optimize_ifun(CSOUND *csound, TREE *root)
+{
+    /* print_tree(csound, "optimize_ifun: before", root); */
+    switch(root->right->type) {
+    case INTEGER_TOKEN:
+    case NUMBER_TOKEN:       /* i(num)    -> num      */
+    case T_IDENT_I:          /* i(ivar)   -> ivar     */
+    case T_IDENT_GI:         /* i(givar)  -> givar    */
+    case T_IDENT_P:          /* i(pN)     -> pN       */
+      root = root->right;
+      break;
+    case T_IDENT_K:          /* i(kvar)   -> i(kvar)  */
+    case T_IDENT_GK:         /* i(gkvar)  -> i(gkvar) */
+      break;
+    case T_FUNCTION:         /* i(fn(x))  -> fn(i(x)) */
+      {
+        TREE *funTree = root->right;
+        funTree->right = create_fun_token(csound, funTree->right, "i");
+        root = funTree;
+      }
+      break;
+    default:                 /* i(A op B) -> i(A) op i(B) */
+      if(root->right->left != NULL)
+        root->right->left = create_fun_token(csound, root->right->left, "i");
+      if(root->right->right != NULL)
+        root->right->right = create_fun_token(csound, root->right->right, "i");
+      root->right->next = root->next;
+      root = root->right;
+      break;
+    }
+    /* print_tree(csound, "optimize_ifun: after", root); */
+    return root;
+}
 
 /** Verifies and optimise; constant fold and opcodes and args are correct*/
-TREE * verify_tree(CSOUND *csound, TREE *root) 
+static TREE * verify_tree1(CSOUND *csound, TREE *root)
 {
-    TREE* ans;
+    TREE *ans, *last;
     double lval, rval;
     //csound->Message(csound, "Verifying AST (NEED TO IMPLEMENT)\n");
-    //    print_tree(csound, "Verify", root);
-    if (root==NULL) return NULL;
-    if (root->left)  {
-      root->left = verify_tree(csound, root->left);
-      if (root->right) {
-        root->right= verify_tree(csound, root->right);
-        if ((root->left->type  == T_INTGR || root->left->type  == T_NUMBER) &&
-            (root->right->type == T_INTGR || root->right->type == T_NUMBER)) {
-          lval = (root->left->type == T_INTGR ?
+    //print_tree(csound, "Verify", root);
+    if (root->right && root->right->type != T_INSTLIST) {
+      if (root->type == T_OPCODE || root->type == T_OPCODE0) {
+        last = root->right;
+        while (last->next) {
+          /* we optimize the i() functions in the opcode */
+          if (last->next->type == T_FUNCTION &&
+              (strcmp(last->next->value->lexeme, "i") == 0)) {
+            TREE *temp = optimize_ifun(csound, last->next);
+            temp->next = last->next->next;
+            last->next = temp;
+          }
+          last = last->next;
+        }
+      }
+      if (root->right->type == T_FUNCTION &&
+          (strcmp(root->right->value->lexeme, "i") == 0)) {  /* i() function */
+        root->right = optimize_ifun(csound, root->right);
+      }
+      last = root->right;
+      while (last->next) {
+        last->next = verify_tree1(csound, last->next);
+        last = last->next;
+      }
+      root->right = verify_tree1(csound, root->right);
+      if (root->left) {
+        if (root->left->type == T_FUNCTION &&
+            (strcmp(root->left->value->lexeme, "i") == 0)) {  /* i() function */
+          root->left = optimize_ifun(csound, root->left);
+        }
+        root->left= verify_tree1(csound, root->left);
+        if ((root->left->type  == INTEGER_TOKEN ||
+             root->left->type  == NUMBER_TOKEN) &&
+            (root->right->type == INTEGER_TOKEN ||
+             root->right->type == NUMBER_TOKEN)) {
+          //print_tree(csound, "numerical case\n", root);
+          lval = (root->left->type == INTEGER_TOKEN ?
                   (double)root->left->value->value :root->left->value->fvalue);
-          rval = (root->right->type == T_INTGR ?
-                  (double)root->right->value->value :root->left->value->fvalue);
+          rval = (root->right->type == INTEGER_TOKEN ?
+                  (double)root->right->value->value :root->right->value->fvalue);
           ans = root->left;
-          ans->type = ans->value->type = T_NUMBER;
+          ans->type = ans->value->type = NUMBER_TOKEN;
+          /* **** Something wrong here -- subtraction confuses memory **** */
           switch (root->type) {
-          case S_PLUS:
+          case '+':
             ans->value->fvalue = lval+rval;
-            mrealloc(csound, ans->value->lexeme, 24);
+            ans->value->lexeme =
+              (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
-            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            ans->next = root->next;
+            //Memory leak!!
+            //mfree(csound, root); mfree(csound root->right);
             return ans;
-          case S_MINUS:
+          case '-':
             ans->value->fvalue = lval-rval;
-            mrealloc(csound, ans->value->lexeme, 24);
+            ans->value->lexeme =
+              (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
-            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            ans->next = root->next;
+            //Memory leak!!
+            //mfree(csound, root); mfree(csound, root->right);
             return ans;
-          case S_TIMES:
+          case '*':
             ans->value->fvalue = lval*rval;
-            mrealloc(csound, ans->value->lexeme, 24);
+            ans->value->lexeme =
+              (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
-            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            ans->next = root->next;
+            //Memory leak!!
+            //mfree(csound, root); mfree(csound, root->right);
             return ans;
-          case S_DIV:
+          case '/':
             ans->value->fvalue = lval/rval;
-            mrealloc(csound, ans->value->lexeme, 24);
+            ans->value->lexeme =
+              (char*)mrealloc(csound, ans->value->lexeme, 24);
             sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
-            //Memory leak!! mfree(csound, root); mfree(csound, root->right);
+            ans->next = root->next;
+            //Memory leak!!
+            //mfree(csound, root); mfree(csound, root->right);
             return ans;
             /* case S_NEQ: */
             /*   break; */
@@ -105,31 +195,89 @@ TREE * verify_tree(CSOUND *csound, TREE *root)
           }
         }
       }
+      else if (root->right->type == INTEGER_TOKEN ||
+               root->right->type == NUMBER_TOKEN) {
+        switch (root->type) {
+        case S_UMINUS:
+          /*print_tree(csound, "root", root);*/
+          ans = root->right;
+          ans->value->fvalue = -(ans->type==INTEGER_TOKEN ? ans->value->value
+                                 : ans->value->fvalue);
+          ans->value->lexeme =
+            (char*)mrealloc(csound, ans->value->lexeme, 24);
+          sprintf(ans->value->lexeme, "%f", ans->value->fvalue);
+          ans->type = ans->value->type = NUMBER_TOKEN;
+          //print_tree(csound, "ans", ans);
+          ans->next = root->next;
+          return ans;
+        default:
+          break;
+        }
+      }
     }
     return root;
 }
 
+TREE * verify_tree(CSOUND *csound, TREE *root)
+{
+    TREE *original=root, *last = NULL;
+    while (root) {
+      TREE *xx = verify_tree1(csound, root);
+      if (xx != root) {
+        xx->next = root->next;
+        if (last) last->next = xx;
+        else original = xx;
+      }
+      last = root;
+      root = root->next;
+    }
+    return original;
+}
 
 /* BISON PARSER FUNCTION */
 int csound_orcwrap()
 {
-    printf("END OF INPUT\n");
+#ifdef DEBUG
+    printf("\n === END OF INPUT ===\n");
+#endif
     return (1);
 }
 
+extern int csound_orcget_lineno(void*);
+extern char *csound_orcget_current_pointer(void *);
 /* BISON PARSER FUNCTION */
 void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
-                     CSOUND *csound, TREE *astTree, char *str)
+                     CSOUND *csound, TREE *astTree, const char *str)
 {
-    //??    extern int yyline;
-    //    extern char* buffer;
-
-    csound->Message(csound, Str("error: %s (token \"%s\")"),
+    char ch;
+    char *p = csound_orcget_current_pointer(yyscanner)-1;
+    int line = csound_orcget_lineno(yyscanner);
+    if (*p=='\0') line--;
+    csound->Message(csound, Str("\nerror: %s  (token \"%s\")"),
                     str, csound_orcget_text(yyscanner));
-    csound->Message(csound, Str(" line %d: %s"),
-                    csound_orcget_lineno(yyscanner), pp->buffer); // buffer has \n at end
+    csound->Message(csound, Str(" line %d:\n>>>"), line);
+    /* if(!strcmp(csound_orcget_text(yyscanner), "\n")) { */
+    /*  csound->Message(csound, Str("error: %s (\"\\n\")"), */
+    /*                 str); */
+    /*  csound->Message(csound, Str(" line %d:\n>>> "), */
+    /*               csound_orcget_lineno(yyscanner)); */
+    /* } */
+    /* else { */
+    /*  csound->Message(csound, Str("\nerror: %s  (token \"%s\")"), */
+    /*                 str, csound_orcget_text(yyscanner)); */
+    /* csound->Message(csound, Str(" line %d:\n>>> "), */
+    /*                 csound_orcget_lineno(yyscanner)+1); */
+    /* } */
+    while ((ch=*--p) != '\n' && ch != '\0');
+    do {
+      ch = *++p;
+      if(ch == '\n') break;
+      csound->Message(csound, "%c", ch);
+    } while (ch != '\n' && ch != '\0');
+    csound->Message(csound, " <<<\n");
 }
 
+
 /**
  * Appends TREE * node to TREE * node using ->next field in struct; walks
  * down the linked list to append at end; checks for NULL's and returns
@@ -148,8 +296,8 @@ TREE* appendToTree(CSOUND * csound, TREE *first, TREE *newlast) {
     /* HACK - Checks to see if first node is uninitialized (sort of)
      * This occurs for rules like in topstatement where the left hand
      * topstatement the first time around is not initialized to anything
-     * useful; the number 400 is arbitrary, chosen as it seemed to be a value
-     * higher than all the type numbers that were being printed out
+     * useful; the number 400 is arbitrary, chosen as it seemed to be a
+     * value higher than all the type numbers that were being printed out
      */
     if (first->type > 400 || first-> type < 0) {
         return newlast;
@@ -168,7 +316,8 @@ TREE* appendToTree(CSOUND * csound, TREE *first, TREE *newlast) {
 
 
 /* USED BY PARSER TO ASSEMBLE TREE NODES */
-TREE* make_node(CSOUND *csound, int type, TREE* left, TREE* right)
+TREE* make_node(CSOUND *csound, int line, int locn, int type,
+                TREE* left, TREE* right)
 {
     TREE *ans;
     ans = (TREE*)mmalloc(csound, sizeof(TREE));
@@ -182,10 +331,13 @@ TREE* make_node(CSOUND *csound, int type, TREE* left, TREE* right)
     ans->next = NULL;
     ans->len = 2;
     ans->rate = -1;
+    ans->line = line;
+    ans->locn  = locn;
+    csound->DebugMsg(csound, "%s(%d) line = %d\n", __FILE__, __LINE__, line);
     return ans;
 }
 
-TREE* make_leaf(CSOUND *csound, int type, ORCTOKEN *v)
+TREE* make_leaf(CSOUND *csound, int line, int locn, int type, ORCTOKEN *v)
 {
     TREE *ans;
     ans = (TREE*)mmalloc(csound, sizeof(TREE));
@@ -200,6 +352,9 @@ TREE* make_leaf(CSOUND *csound, int type, ORCTOKEN *v)
     ans->len = 0;
     ans->rate = -1;
     ans->value = v;
+    ans->line = line;
+    ans->locn  = locn;
+    csound->DebugMsg(csound, "%s(%d) line = %d\n", __FILE__, __LINE__, line);
     return ans;
 }
 
@@ -247,94 +402,84 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     csound->Message(csound, "TYPE: %d ", l->type);
 
     switch (l->type) {
-    case S_COM:
-      csound->Message(csound,"S_COM:\n"); break;
-    case S_Q:
-      csound->Message(csound,"S_Q:\n"); break;
-    case S_COL:
-      csound->Message(csound,"S_COL:\n"); break;
-    case S_NOT:
-      csound->Message(csound,"S_NOT:\n"); break;
-    case S_PLUS:
-      csound->Message(csound,"S_PLUS:\n"); break;
-    case S_MINUS:
-      csound->Message(csound,"S_MINUS:\n"); break;
-    case S_TIMES:
-      csound->Message(csound,"S_TIMES:\n"); break;
-    case S_DIV:
-      csound->Message(csound,"S_DIV:\n"); break;
-    case S_MOD:
-      csound->Message(csound,"S_MOD:\n"); break;
-    case S_POW:
-      csound->Message(csound,"S_POW:\n"); break;
-    case S_NL:
-      csound->Message(csound,"S_NL:\n"); break;
-    case S_LB:
-      csound->Message(csound,"S_LB:\n"); break;
-    case S_RB:
-      csound->Message(csound,"S_RB:\n"); break;
+    case ',':
+    case '?':
+    case ':':
+    case '!':
+    case '+':
+    case '-':
+    case '*':
+    case '/':
+    case '%':
+    case '^':
+    case '(':
+    case ')':
+    case '=':
+      csound->Message(csound,"%c:(%d:%d)\n", l->type, l->line, l->locn); break;
+    case NEWLINE:
+      csound->Message(csound,"NEWLINE:(%d:%d)\n", l->line, l->locn); break;
     case S_NEQ:
-      csound->Message(csound,"S_NEQ:\n"); break;
+      csound->Message(csound,"S_NEQ:(%d:%d)\n", l->line, l->locn); break;
     case S_AND:
-      csound->Message(csound,"S_AND:\n"); break;
+      csound->Message(csound,"S_AND:(%d:%d)\n", l->line, l->locn); break;
     case S_OR:
-      csound->Message(csound,"S_OR:\n"); break;
+      csound->Message(csound,"S_OR:(%d:%d)\n", l->line, l->locn); break;
     case S_LT:
-      csound->Message(csound,"S_LT:\n"); break;
+      csound->Message(csound,"S_LT:(%d:%d)\n", l->line, l->locn); break;
     case S_LE:
-      csound->Message(csound,"S_LE:\n"); break;
+      csound->Message(csound,"S_LE:(%d:%d)\n", l->line, l->locn); break;
     case S_EQ:
-      csound->Message(csound,"S_EQ:\n"); break;
-    case S_ASSIGN:
-      csound->Message(csound,"S_ASSIGN:\n"); break;
+      csound->Message(csound,"S_EQ:(%d:%d)\n", l->line, l->locn); break;
     case S_TASSIGN:
-      csound->Message(csound,"S_TASSIGN:\n"); break;
+      csound->Message(csound,"S_TASSIGN:(%d:%d)\n", l->line, l->locn); break;
     case S_TABREF:
-      csound->Message(csound,"S_TABREF:\n"); break;
+      csound->Message(csound,"S_TABREF:(%d:%d)\n", l->line, l->locn); break;
     case S_GT:
-      csound->Message(csound,"S_GT:\n"); break;
+      csound->Message(csound,"S_GT:(%d:%d)\n", l->line, l->locn); break;
     case S_GE:
-      csound->Message(csound,"S_GE:\n"); break;
-    case T_LABEL:
-      csound->Message(csound,"T_LABEL: %s\n", l->value->lexeme); break;
-    case T_IF:
-      csound->Message(csound,"T_IF:\n"); break;
-    case T_THEN:
-          csound->Message(csound,"T_THEN:\n"); break;
-    case T_ITHEN:
-          csound->Message(csound,"T_ITHEN:\n"); break;
-    case T_KTHEN:
-          csound->Message(csound,"T_KTHEN:\n"); break;
-    case T_ELSEIF:
-          csound->Message(csound,"T_ELSEIF:\n"); break;
-    case T_ELSE:
-          csound->Message(csound,"T_ELSE:\n"); break;
-    case T_UNTIL:
-          csound->Message(csound,"T_UNTIL:\n"); break;
-    case T_DO:
-          csound->Message(csound,"T_DO:\n"); break;
-    case T_OD:
-          csound->Message(csound,"T_OD:\n"); break;
-    case T_GOTO:
-      csound->Message(csound,"T_GOTO:\n"); break;
-    case T_IGOTO:
-      csound->Message(csound,"T_IGOTO:\n"); break;
-    case T_KGOTO:
-      csound->Message(csound,"T_KGOTO:\n"); break;
-    case T_SRATE:
-      csound->Message(csound,"T_SRATE:\n"); break;
-    case T_KRATE:
-      csound->Message(csound,"T_KRATE:\n"); break;
-    case T_KSMPS:
-      csound->Message(csound,"T_KSMPS:\n"); break;
-    case T_NCHNLS:
-      csound->Message(csound,"T_NCHNLS:\n"); break;
-    case T_NCHNLSI:
-      csound->Message(csound,"T_NCHNLSI:\n"); break;
-    case T_INSTR:
-      csound->Message(csound,"T_INSTR:\n"); break;
-    case T_STRCONST:
-      csound->Message(csound,"T_STRCONST: %s\n", l->value->lexeme); break;
+      csound->Message(csound,"S_GE:(%d:%d)\n", l->line, l->locn); break;
+    case LABEL_TOKEN:
+      csound->Message(csound,"LABEL_TOKEN: %s\n", l->value->lexeme); break;
+    case IF_TOKEN:
+      csound->Message(csound,"IF_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case THEN_TOKEN:
+          csound->Message(csound,"THEN_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case ITHEN_TOKEN:
+          csound->Message(csound,"ITHEN_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case KTHEN_TOKEN:
+          csound->Message(csound,"KTHEN_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case ELSEIF_TOKEN:
+          csound->Message(csound,"ELSEIF_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case ELSE_TOKEN:
+          csound->Message(csound,"ELSE_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case UNTIL_TOKEN:
+          csound->Message(csound,"UNTIL_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case DO_TOKEN:
+          csound->Message(csound,"DO_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case OD_TOKEN:
+          csound->Message(csound,"OD_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case GOTO_TOKEN:
+      csound->Message(csound,"GOTO_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case IGOTO_TOKEN:
+      csound->Message(csound,"IGOTO_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case KGOTO_TOKEN:
+      csound->Message(csound,"KGOTO_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case SRATE_TOKEN:
+      csound->Message(csound,"SRATE_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case KRATE_TOKEN:
+      csound->Message(csound,"KRATE_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case ZERODBFS_TOKEN:
+      csound->Message(csound,"ZERODFFS_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case KSMPS_TOKEN:
+      csound->Message(csound,"KSMPS_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case NCHNLS_TOKEN:
+      csound->Message(csound,"NCHNLS_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case NCHNLSI_TOKEN:
+      csound->Message(csound,"NCHNLSI_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case INSTR_TOKEN:
+      csound->Message(csound,"INSTR_TOKEN:(%d:%d)\n", l->line, l->locn); break;
+    case STRING_TOKEN:
+      csound->Message(csound,"STRING_TOKEN: %s\n", l->value->lexeme); break;
     case T_IDENT:
       csound->Message(csound,"T_IDENT: %s\n", l->value->lexeme); break;
     case T_IDENT_I:
@@ -371,14 +516,14 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
       csound->Message(csound,"IDENT_B: %s\n", l->value->lexeme); break;
     case T_IDENT_b:
       csound->Message(csound,"IDENT_b: %s\n", l->value->lexeme); break;
-    case T_INTGR:
-      csound->Message(csound,"T_INTGR: %d\n", l->value->value); break;
-    case T_NUMBER:
-      csound->Message(csound,"T_NUMBER: %f\n", l->value->fvalue); break;
+    case INTEGER_TOKEN:
+      csound->Message(csound,"INTEGER_TOKEN: %d\n", l->value->value); break;
+    case NUMBER_TOKEN:
+      csound->Message(csound,"NUMBER_TOKEN: %f\n", l->value->fvalue); break;
     case S_ANDTHEN:
-      csound->Message(csound,"S_ANDTHEN:\n"); break;
+      csound->Message(csound,"S_ANDTHEN:(%d:%d)\n", l->line, l->locn); break;
     case S_APPLY:
-      csound->Message(csound,"S_APPLY:\n"); break;
+      csound->Message(csound,"S_APPLY:(%d:%d)\n", l->line, l->locn); break;
     case T_OPCODE0:
       csound->Message(csound,"T_OPCODE0: %s\n", l->value->lexeme); break;
     case T_OPCODE:
@@ -386,11 +531,11 @@ void print_tree_i(CSOUND *csound, TREE *l, int n)
     case T_FUNCTION:
       csound->Message(csound,"T_FUNCTION: %s\n", l->value->lexeme); break;
     case S_UMINUS:
-        csound->Message(csound,"S_UMINUS:\n"); break;
+        csound->Message(csound,"S_UMINUS:(%d:%d)\n", l->line, l->locn); break;
     case T_INSTLIST:
-        csound->Message(csound,"T_INSTLIST:\n"); break;
+        csound->Message(csound,"T_INSTLIST:(%d:%d)\n", l->line, l->locn); break;
     default:
-      csound->Message(csound,"t:%d\n", l->type);
+      csound->Message(csound,"unknown:%d(%d:%d)\n", l->type, l->line, l->locn);
     }
 
     print_tree_i(csound, l->left,n+1);
@@ -416,32 +561,26 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
     csound->Message(csound, "<tree%s type=\"%d\" ", child[which], l->type);
 
     switch (l->type) {
-    case S_COM:
-      csound->Message(csound,"name=\"S_COM\""); break;
-    case S_Q:
-      csound->Message(csound,"name=\"S_Q\""); break;
-    case S_COL:
-      csound->Message(csound,"name=\"S_COL\""); break;
-    case S_NOT:
-      csound->Message(csound,"name=\"S_NOT\""); break;
-    case S_PLUS:
-      csound->Message(csound,"name=\"S_PLUS\""); break;
-    case S_MINUS:
-      csound->Message(csound,"name=\"S_MINUS\""); break;
-    case S_TIMES:
-      csound->Message(csound,"name=\"S_TIMES\""); break;
-    case S_DIV:
-      csound->Message(csound,"name=\"S_DIV\""); break;
-    case S_MOD:
-      csound->Message(csound,"name=\"S_MOD\""); break;
-    case S_POW:
-      csound->Message(csound,"name=\"S_POW\""); break;
-    case S_NL:
-      csound->Message(csound,"name=\"S_NL\""); break;
-    case S_LB:
-      csound->Message(csound,"name=\"S_LB\""); break;
-    case S_RB:
-      csound->Message(csound,"name=\"S_RB\""); break;
+    case ',':
+    case '?':
+    case ':':
+    case '!':
+    case '+':
+    case '-':
+    case '*':
+    case '/':
+    case '%':
+    case '^':
+    case '(':
+    case ')':
+    case '=':
+    case '|':
+    case '&':
+    case '#':
+    case '~':
+      csound->Message(csound,"name=\"%c\"", l->type); break;
+    case NEWLINE:
+      csound->Message(csound,"name=\"NEWLINE\""); break;
     case S_NEQ:
       csound->Message(csound,"name=\"S_NEQ\""); break;
     case S_AND:
@@ -454,8 +593,6 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
       csound->Message(csound,"name=\"S_LE\""); break;
     case S_EQ:
       csound->Message(csound,"name=\"S_EQ\""); break;
-    case S_ASSIGN:
-      csound->Message(csound,"name=\"S_ASSIGN\""); break;
     case S_TASSIGN:
       csound->Message(csound,"name=\"S_TASSIGN\""); break;
     case S_TABREF:
@@ -464,58 +601,52 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
       csound->Message(csound,"name=\"S_GT\""); break;
     case S_GE:
       csound->Message(csound,"name=\"S_GE\""); break;
-    case S_BITOR:
-      csound->Message(csound,"name=\"S_BITOR\""); break;
-    case S_BITAND:
-      csound->Message(csound,"name=\"S_BITAND\""); break;
-    case S_BITSHR:
-      csound->Message(csound,"name=\"S_BITSHR\""); break;
-    case S_BITSHL:
-      csound->Message(csound,"name=\"S_BITSHL\""); break;
-    case S_NEQV:
-      csound->Message(csound,"name=\"S_NEQV\""); break;
-    case S_BITNOT:
-      csound->Message(csound,"name=\"S_BITNOT\""); break;
-    case T_LABEL:
-      csound->Message(csound,"name=\"T_LABEL\" label=\"%s\"",
+    case S_BITSHIFT_RIGHT:
+      csound->Message(csound,"name=\"S_BITSHIFT_RIGHT\""); break;
+    case S_BITSHIFT_LEFT:
+      csound->Message(csound,"name=\"S_BITSHIFT_LEFT\""); break;
+    case LABEL_TOKEN:
+      csound->Message(csound,"name=\"LABEL_TOKEN\" label=\"%s\"",
                       l->value->lexeme); break;
-    case T_IF:
-      csound->Message(csound,"name=\"T_IF\""); break;
-    case T_THEN:
-          csound->Message(csound,"name=\"T_THEN\""); break;
-    case T_ITHEN:
-          csound->Message(csound,"name=\"T_ITHEN\""); break;
-    case T_KTHEN:
-          csound->Message(csound,"name=\"T_KTHEN\""); break;
-    case T_ELSEIF:
-          csound->Message(csound,"name=\"T_ELSEIF\""); break;
-    case T_ELSE:
-          csound->Message(csound,"name=\"T_ELSE\""); break;
-    case T_UNTIL:
-          csound->Message(csound,"name=\"T_UNTIL\""); break;
-    case T_DO:
-          csound->Message(csound,"name=\"T_DO\""); break;
-    case T_OD:
-          csound->Message(csound,"name=\"T_OD\""); break;
-    case T_GOTO:
-      csound->Message(csound,"name=\"T_GOTO\""); break;
-    case T_IGOTO:
-      csound->Message(csound,"name=\"T_IGOTO\""); break;
-    case T_KGOTO:
-      csound->Message(csound,"name=\"T_KGOTO\""); break;
-    case T_SRATE:
-      csound->Message(csound,"name=\"T_SRATE\""); break;
-    case T_KRATE:
-      csound->Message(csound,"name=\"T_KRATE\""); break;
-    case T_KSMPS:
-      csound->Message(csound,"name=\"T_KSMPS\""); break;
-    case T_NCHNLS:
-      csound->Message(csound,"name=\"T_NCHNLS\""); break;
-    case T_NCHNLSI:
-      csound->Message(csound,"name=\"T_NCHNLSI\""); break;
-    case T_INSTR:
-      csound->Message(csound,"name=\"T_INSTR\""); break;
-    case T_STRCONST:
+    case IF_TOKEN:
+      csound->Message(csound,"name=\"IF_TOKEN\""); break;
+    case THEN_TOKEN:
+          csound->Message(csound,"name=\"THEN_TOKEN\""); break;
+    case ITHEN_TOKEN:
+          csound->Message(csound,"name=\"ITHEN_TOKEN\""); break;
+    case KTHEN_TOKEN:
+          csound->Message(csound,"name=\"KTHEN_TOKEN\""); break;
+    case ELSEIF_TOKEN:
+          csound->Message(csound,"name=\"ELSEIF_TOKEN\""); break;
+    case ELSE_TOKEN:
+          csound->Message(csound,"name=\"ELSE_TOKEN\""); break;
+    case UNTIL_TOKEN:
+          csound->Message(csound,"name=\"UNTIL_TOKEN\""); break;
+    case DO_TOKEN:
+          csound->Message(csound,"name=\"DO_TOKEN\""); break;
+    case OD_TOKEN:
+          csound->Message(csound,"name=\"OD_TOKEN\""); break;
+    case GOTO_TOKEN:
+      csound->Message(csound,"name=\"GOTO_TOKEN\""); break;
+    case IGOTO_TOKEN:
+      csound->Message(csound,"name=\"IGOTO_TOKEN\""); break;
+    case KGOTO_TOKEN:
+      csound->Message(csound,"name=\"KGOTO_TOKEN\""); break;
+    case SRATE_TOKEN:
+      csound->Message(csound,"name=\"SRATE_TOKEN\""); break;
+    case KRATE_TOKEN:
+      csound->Message(csound,"name=\"KRATE_TOKEN\""); break;
+    case ZERODBFS_TOKEN:
+      csound->Message(csound,"name=\"ZERODBFS_TOKEN\""); break;
+    case KSMPS_TOKEN:
+      csound->Message(csound,"name=\"KSMPS_TOKEN\""); break;
+    case NCHNLS_TOKEN:
+      csound->Message(csound,"name=\"NCHNLS_TOKEN\""); break;
+    case NCHNLSI_TOKEN:
+      csound->Message(csound,"name=\"NCHNLSI_TOKEN\""); break;
+    case INSTR_TOKEN:
+      csound->Message(csound,"name=\"INSTR_TOKEN\""); break;
+    case STRING_TOKEN:
       csound->Message(csound,"name=\"T_STRCONST\" str=\"%s\"",
                       l->value->lexeme); break;
     case T_IDENT:
@@ -572,11 +703,11 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
     case T_IDENT_b:
       csound->Message(csound,"name=\"IDENT_b\" varname=\"%s\"",
                       l->value->lexeme); break;
-    case T_INTGR:
-      csound->Message(csound,"name=\"T_INTGR\" value=\"%d\"",
+    case INTEGER_TOKEN:
+      csound->Message(csound,"name=\"INTEGER_TOKEN\" value=\"%d\"",
                       l->value->value); break;
-    case T_NUMBER:
-      csound->Message(csound,"name=\"T_NUMBER\" value=\"%f\" type=%d",
+    case NUMBER_TOKEN:
+      csound->Message(csound,"name=\"NUMBER_TOKEN\" value=\"%f\" type=%d",
                       l->value->fvalue, l->value->type); break;
     case S_ANDTHEN:
       csound->Message(csound,"name=\"S_ANDTHEN\""); break;
@@ -595,19 +726,19 @@ static void print_tree_xml(CSOUND *csound, TREE *l, int n, int which)
         csound->Message(csound,"name=\"S_UMINUS\""); break;
     case T_INSTLIST:
         csound->Message(csound,"name=\"T_INSTLIST\""); break;
-    case T_UDO:
-        csound->Message(csound,"name=\"T_UDO\""); break;
-    case T_UDO_ANS:
-        csound->Message(csound,"name=\"T_UDO_ANS\" signature=\"%s\"",
+    case UDO_TOKEN:
+        csound->Message(csound,"name=\"UDO_TOKEN\""); break;
+    case UDO_ANS_TOKEN:
+        csound->Message(csound,"name=\"UDO_ANS_TOKEN\" signature=\"%s\"",
                         l->value->lexeme); break;
-    case T_UDO_ARGS:
-        csound->Message(csound,"name=\"T_UDO_ARGS\" signature=\"%s\"",
+    case UDO_ARGS_TOKEN:
+        csound->Message(csound,"name=\"UDO_ARGS_TOKEN\" signature=\"%s\"",
                         l->value->lexeme); break;
     default:
-      csound->Message(csound,"name=\"unknown\"");
+      csound->Message(csound,"name=\"unknown\"(%d)", l->type);
     }
 
-    csound->Message(csound, " >\n");
+    csound->Message(csound, " (%d:%d)>\n", l->line, l->locn);
 
     print_tree_xml(csound, l->left,n+1, TREE_LEFT);
     print_tree_xml(csound, l->right,n+1, TREE_RIGHT);
@@ -638,7 +769,7 @@ void print_tree(CSOUND * csound, char* msg, TREE *l)
 
 void handle_optional_args(CSOUND *csound, TREE *l)
 {
-    if (l == NULL || l->type == T_LABEL) return;
+    if (l == NULL || l->type == LABEL_TOKEN) return;
 
     int opnum = find_opcode(csound, l->value->lexeme);
     OENTRY *ep = csound->opcodlst + opnum;
@@ -660,36 +791,36 @@ void handle_optional_args(CSOUND *csound, TREE *l)
         switch (ep->intypes[incnt]) {
         case 'O':             /* Will this work?  Doubtful code.... */
         case 'o':
-          temp = make_leaf(csound, T_INTGR, make_int(csound, "0"));
+          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "0"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
         case 'P':
         case 'p':
-          temp = make_leaf(csound, T_INTGR, make_int(csound, "1"));
+          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "1"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
         case 'q':
-          temp = make_leaf(csound, T_INTGR, make_int(csound, "10"));
+          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "10"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
 
         case 'V':
         case 'v':
-          temp = make_leaf(csound, T_NUMBER, make_num(csound, ".5"));
+          temp = make_leaf(csound, l->line, l->locn, NUMBER_TOKEN, make_num(csound, ".5"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
         case 'h':
-          temp = make_leaf(csound, T_INTGR, make_int(csound, "127"));
+          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "127"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
         case 'J':
         case 'j':
-          temp = make_leaf(csound, T_INTGR, make_int(csound, "-1"));
+          temp = make_leaf(csound, l->line, l->locn, INTEGER_TOKEN, make_int(csound, "-1"));
           if (l->right==NULL) l->right = temp;
           else appendToTree(csound, l->right, temp);
           break;
@@ -699,7 +830,9 @@ void handle_optional_args(CSOUND *csound, TREE *l)
           nreqd--;
           break;
         default:
-          synterr(csound, Str("insufficient required arguments"));
+          synterr(csound,
+                  Str("insufficient required arguments for opcode %s on line %d\n"),
+                  ep->opname, l->line, l->locn);
         }
         incnt++;
       } while (incnt < nreqd);
@@ -707,7 +840,7 @@ void handle_optional_args(CSOUND *csound, TREE *l)
 }
 
 char tree_argtyp(CSOUND *csound, TREE *tree) {
-    if (tree->type == T_INTGR || tree->type == T_NUMBER) {
+    if (tree->type == INTEGER_TOKEN || tree->type == NUMBER_TOKEN) {
       return 'i';
     }
 
@@ -715,15 +848,13 @@ char tree_argtyp(CSOUND *csound, TREE *tree) {
 }
 
 void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
-    if (tree->type == S_ASSIGN) {
+    if (tree->type == '=') {
       /* BUG: tree->right->value may be NULL */
       /* if (tree->right->value) */
-        tree->value->lexeme = get_assignment_type(csound,
-                                                  tree->left->value->lexeme,
-                                                  tree->right/*->value->lexeme*/);
-      /* else {                    /\* Conditional expression so broken  *\/ */
-      /*   print_tree(csound, "Odd case\n", tree); */
-      /* } */
+      tree->value->lexeme =
+        get_assignment_type(csound,
+                            tree->left->value->lexeme,
+                            tree->right/*->value->lexeme*/);
       return;
     }
     else if (tree->type==0) {
@@ -755,13 +886,13 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
 
           if (PARSER_DEBUG) csound->Message(csound, "New Value: %s\n", str);
 
-          /*if (find_opcode(csound, str) == 0) {*/
-          /* synterr(csound, Str("failed to find %s, output arg '%s' illegal type"),
-             str, ST(group)[ST(nxtest)]);*/    /* report syntax error     */
-          /*ST(nxtest) = 100; */                    /* step way over this line */
-          /*goto tstnxt;*/                          /* & go to next            */
-          /*break;*/
-          /*}*/
+     /*if (find_opcode(csound, str) == 0) {*/
+     /* synterr(csound, Str("failed to find %s, output arg '%s' illegal type"),
+        str, ST(group)[ST(nxtest)]);*/    /* report syntax error     */
+     /*ST(nxtest) = 100; */                    /* step way over this line */
+     /*goto tstnxt;*/                          /* & go to next            */
+     /*break;*/
+     /*}*/
           tree->value->lexeme = (char *)mrealloc(csound, tree->value->lexeme,
                                                  strlen(str) + 1);
           strcpy(tree->value->lexeme, str);
@@ -825,15 +956,14 @@ void handle_polymorphic_opcode(CSOUND* csound, TREE * tree) {
         default:
           csound->Message(csound, "Impossible case\n");
           break;
-          /*strcpy(str, ST(linopcod));*/  /* unknown code: use original opcode   */
         }
 
-        /*if (!(isopcod(csound, str))) {*/
-        /* if opcode is not found: report syntax error     */
-        /*synterr(csound, Str("failed to find %s, input arg illegal type"), str);*/
-        /*ST(nxtest) = 100;*/                       /* step way over this line */
-        /*goto tstnxt;*/                            /* & go to next            */
-        /*}
+   /*if (!(isopcod(csound, str))) {*/
+   /* if opcode is not found: report syntax error     */
+   /*synterr(csound, Str("failed to find %s, input arg illegal type"), str);*/
+   /*ST(nxtest) = 100;*/                       /* step way over this line */
+   /*goto tstnxt;*/                            /* & go to next            */
+   /*}
           ST(linopnum) = ST(opnum);
           ST(linopcod) = ST(opcod);
           csound->DebugMsg(csound, Str("modified opcod: %s"), ST(opcod));*/
