@@ -637,7 +637,8 @@ int csoundIsNameJustFilename(const char *name)
  *  conform to the conventions for the current platform (begin with ':'
  *  on MacOS 9 and not begin with DIRSEP on others).
  */
-char* csoundConcatenatePaths(CSOUND* csound, const char *path1, const char *path2)
+char* csoundConcatenatePaths(CSOUND* csound, const char *path1,
+                             const char *path2)
 {
     char *result;
     const char *start2;
@@ -788,7 +789,9 @@ char *csoundGetDirectoryForPath(CSOUND* csound, const char * path) {
     /* do we need to worry about ~/ on *nix systems ? */
     /* we have a relative path or just a filename */
     cwd = mmalloc(csound, 512);
-    getcwd(cwd, 512);
+    if (UNLIKELY(getcwd(cwd, 512)==NULL)) {
+      csoundDie(csound, "Current directory path name too long\n");
+    }
 
     if (lastIndex == NULL) {
         return cwd;
@@ -814,7 +817,7 @@ static FILE *csoundFindFile_Std(CSOUND *csound, char **fullName,
 {
     FILE  *f;
     char  *name, *name2, **searchPath;
-    int   len;
+    //int   len;
 
     *fullName = NULL;
     if ((name = csoundConvertPathname(csound, filename)) == NULL)
@@ -845,7 +848,7 @@ static FILE *csoundFindFile_Std(CSOUND *csound, char **fullName,
     if (envList != NULL && envList[0] != '\0' &&
         (searchPath = csoundGetSearchPathFromEnv((CSOUND*) csound, envList))
           != NULL) {
-      len = (int) strlen(name) + 1;
+      //len = (int) strlen(name) + 1;
       while (*searchPath != NULL) {
         name2 = csoundConcatenatePaths(csound, *searchPath, name);
         f = fopen(name2, mode);
@@ -876,7 +879,7 @@ static int csoundFindFile_Fd(CSOUND *csound, char **fullName,
                              const char *envList)
 {
     char  *name, *name2, **searchPath;
-    int   len, fd;
+    int   fd;
 
     *fullName = NULL;
     if ((name = csoundConvertPathname(csound, filename)) == NULL)
@@ -907,7 +910,7 @@ static int csoundFindFile_Fd(CSOUND *csound, char **fullName,
     if (envList != NULL && envList[0] != '\0' &&
         (searchPath = csoundGetSearchPathFromEnv((CSOUND*) csound, envList))
           != NULL) {
-      len = (int) strlen(name) + 1;
+      //len = (int) strlen(name) + 1;
       while (*searchPath != NULL) {
         name2 = csoundConcatenatePaths(csound, *searchPath, name);
         if (!write_mode)
@@ -1062,7 +1065,7 @@ void *csoundFileOpen(CSOUND *csound, void *fd, int type,
  * used as metadata to be passed to the host application's FileOpenCallback.
  *
  * int csFileType:
- *   A value from the enumeration CSOUND_FILETYPES (see CsoundCore.h)
+ *   A value from the enumeration CSOUND_FILETYPES (see soundCore.h)
  * int isTemporary:
  *   1 if this file will be deleted when Csound is finished.
  *   Otherwise, 0.
@@ -1191,7 +1194,8 @@ void *csoundFileOpenWithType(CSOUND *csound, void *fd, int type,
                       (type == CSFILE_STD && ((char*)param)[0] == 'w'));
       if (csFileType == CSFTYPE_UNKNOWN_AUDIO && type == CSFILE_SND_R)
         csFileType = sftype2csfiletype(((SF_INFO*)param)->format);
-      csound->FileOpenCallback_(csound, p->fullName, csFileType, writing, isTemporary);
+      csound->FileOpenCallback_(csound, p->fullName, csFileType,
+                                writing, isTemporary);
     }
     /* return with opaque file handle */
     return (void*) p;
