@@ -30,6 +30,7 @@
 #include "remote.h"
 #include <math.h>
 # include "cscore.h"
+#include "corfile.h"
 
 #define SEGAMPS AMPLMSG
 #define SORMSG  RNGEMSG
@@ -38,7 +39,7 @@ extern  int     MIDIinsert(CSOUND *, int, MCHNBLK*, MEVENT*);
 extern  int     insert(CSOUND *, int, EVTBLK*);
 extern  void    MidiOpen(CSOUND *);
 extern  void    m_chn_init_all(CSOUND *);
-extern  void    scsort(CSOUND *, FILE *, FILE *);
+extern  void    scsortstr(CSOUND *, CORFIL *);
 extern  void    infoff(CSOUND*, MYFLT), orcompact(CSOUND*);
 extern  void    beatexpire(CSOUND *, double), timexpire(CSOUND *, double);
 extern  void    sfopenin(CSOUND *), sfopenout(CSOUND*), sfnopenout(CSOUND*);
@@ -84,7 +85,7 @@ static void settempo(CSOUND *csound, MYFLT tempo)
 {
     if (tempo <= FL(0.0)) return;
     if (csound->oparms->Beatmode==1)
-      csound->ibeatTime = (int)(csound->esr*60.0 / (double) tempo);
+      csound->ibeatTime = (int64_t)(csound->esr*60.0 / (double) tempo);
     csound->curBeat_inc = (double) tempo / (60.0 * (double) csound->global_ekr);
 }
 
@@ -271,14 +272,8 @@ int musmon(CSOUND *csound)
         sfnopenout(csound);
     }
 
-    if (!(csound->scfp = fopen(O->playscore, "r"))) {
-      if (UNLIKELY(!O->Linein)) {
-        csoundDie(csound, Str("cannot reopen %s"), O->playscore);
-      }
-    }
-    /* notify the host if it asked */
-    csoundNotifyFileOpened(csound, O->playscore, CSFTYPE_SCORE_OUT, 0,
-                             (csound->tempStatus & csPlayScoMask)!=0);
+    corfile_flush(O->playscore);
+    //csound->scfp
     if (UNLIKELY(O->usingcscore)) {
       if (ST(lsect) == NULL) {
         ST(lsect) = (EVENT*) mmalloc(csound, sizeof(EVENT));
@@ -294,26 +289,37 @@ int musmon(CSOUND *csound)
       /* call cscore, optionally re-enter via lplay() */
       csound->cscoreCallback_(csound);
       fclose(csound->oscfp); csound->oscfp = NULL;
-      fclose(csound->scfp); csound->scfp = NULL;
+      if (csound->scfp != NULL) {
+        fclose(csound->scfp);
+        csound->scfp = NULL;
+      }
       if (ST(lplayed))
         return 0;
 
       /*  read from cscore.out */
-      if (UNLIKELY(!(csound->scfp = fopen("cscore.out", "r"))))
+      if (UNLIKELY(!(csound->scfp = fopen("cscore.out", "r")))) {
         csoundDie(csound, Str("cannot reopen cscore.out"));
+      }
+      else {
+        CORFIL *inf = corfile_create_w();
+        int c;
+        while ((c=getc(csound->scfp))!=EOF) corfile_putc(c, inf);
+        corfile_rewind(inf);
+        csound->scorestr = inf;
+        corfile_rm(&csound->scstr);
+      }
       csoundNotifyFileOpened(csound, "cscore.out", CSFTYPE_SCORE_OUT, 0, 0);
       /* write to cscore.srt */
      if (UNLIKELY(!(csound->oscfp = fopen("cscore.srt", "w"))))
         csoundDie(csound, Str("cannot reopen cscore.srt"));
       csoundNotifyFileOpened(csound, "cscore.srt", CSFTYPE_SCORE_OUT, 1, 0);
       csound->Message(csound, Str("sorting cscore.out ..\n"));
-      scsort(csound, csound->scfp, csound->oscfp);  /* call the sorter again */
+      /* csound->scorestr = copy_to_corefile(csound, "cscore.srt", NULL, 1); */
+      scsortstr(csound, csound->scorestr);  /* call the sorter again */
       fclose(csound->scfp); csound->scfp = NULL;
+      fputs(corfile_body(csound->scstr), csound->oscfp);
       fclose(csound->oscfp); csound->oscfp = NULL;
       csound->Message(csound, Str("\t... done\n"));
-      if (UNLIKELY(!(csound->scfp = fopen("cscore.srt", "r")))) /*  rd from cscore.srt */
-        csoundDie(csound, Str("cannot reopen cscore.srt"));
-      csoundNotifyFileOpened(csound, "cscore.srt", CSFTYPE_SCORE_OUT, 0, 0);
       csound->Message(csound, Str("playing from cscore.srt\n"));
       O->usingcscore = 0;
     }
@@ -388,10 +394,8 @@ PUBLIC int csoundCleanup(CSOUND *csound)
       free(p);
     }
     orcompact(csound);
-    if (csound->scfp) {
-      fclose(csound->scfp); csound->scfp = NULL;
-    }
-  
+    corfile_rm(&csound->scstr);
+
     /* print stats only if musmon was actually run */
     if (UNLIKELY(csound->musmonGlobals != NULL)) {
       csound->Message(csound, Str("end of score.\t\t   overall amps:"));
@@ -413,12 +417,12 @@ PUBLIC int csoundCleanup(CSOUND *csound)
                               csound->perferrcnt);
       print_benchmark_info(csound, Str("end of performance"));
     }
-     
+
     /* close line input (-L) */
     RTclose(csound);
     /* close MIDI input */
     MidiClose(csound);
- 
+
     /* IV - Feb 03 2005: do not need to call rtclose from here, */
     /* as sfclosein/sfcloseout will do that. */
     if (!csound->enableHostImplementedAudioIO) {
@@ -431,7 +435,7 @@ PUBLIC int csoundCleanup(CSOUND *csound)
     if (csound->remoteGlobals) remote_Cleanup(csound);
     if (csound->oparms->ringbell)
       cs_beep(csound);
-   
+
     return dispexit(csound);    /* hold or terminate the display output     */
 }
 
@@ -700,8 +704,8 @@ static int process_score_event(CSOUND *csound, EVTBLK *evt, int rtEvt)
       break;
     case 'a':
       {
-        int kCnt;
-        kCnt = (int) ((double) csound->global_ekr * (double) evt->p[3] + 0.5);
+        int64_t kCnt;
+        kCnt = (int64_t) ((double) csound->global_ekr * (double) evt->p[3] + 0.5);
         if (kCnt > csound->advanceCnt) {
           csound->advanceCnt = kCnt;
           csound->Message(csound,
@@ -720,7 +724,8 @@ static void process_midi_event(CSOUND *csound, MEVENT *mep, MCHNBLK *chn)
 {
     int n, insno = chn->insno;
     if (mep->type == NOTEON_TYPE && mep->dat2) {      /* midi note ON: */
-      if (UNLIKELY((n = MIDIinsert(csound, insno, chn, mep)))) {     /* alloc,init,activ */
+      if (UNLIKELY((n = MIDIinsert(csound, insno, chn, mep)))) {
+        /* alloc,init,activ */
         csound->Message(csound,
                         Str("\t\t   T%7.3f - note deleted. "), csound->curp2);
         {
@@ -800,7 +805,7 @@ static int process_rt_event(CSOUND *csound, int sensType)
     return retval;
 }
 
-#define RNDINT(x) ((int) ((double) (x) + ((double) (x) < 0.0 ? -0.5 : 0.5)))
+#define RNDINT64(x) ((int64_t) ((double) (x) + ((double) (x) < 0.0 ? -0.5 : 0.5)))
 
 extern  int     sensMidi(CSOUND *);
 
@@ -880,7 +885,7 @@ int sensevents(CSOUND *csound)
           else                                          /* else lcode   */
             memcpy((void*) e, (void*) &(ST(lsect)->strarg), sizeof(EVTBLK));
         } else
-          if (!(rdscor(csound, e)))       /*   or rd nxt evt from scorfil */
+          if (!(rdscor(csound, e)))           /* or rd nxt evt from scstr */
             e->opcod = 'e';
         csound->currevent = e;
         switch (e->opcod) {
@@ -914,10 +919,10 @@ int sensevents(CSOUND *csound)
       /* calculate the number of k-periods remaining until next event */
       if (O->Beatmode)
         csound->cyclesRemaining =
-          RNDINT((csound->nxtbt - csound->curBeat) / csound->curBeat_inc);
+          RNDINT64((csound->nxtbt - csound->curBeat) / csound->curBeat_inc);
       else {
         csound->cyclesRemaining =
-          RNDINT((csound->nxtim*csound->esr - csound->icurTime) / csound->ksmps);
+          RNDINT64((csound->nxtim*csound->esr - csound->icurTime) / csound->ksmps);
         csound->nxtim = (csound->cyclesRemaining*csound->ksmps+csound->icurTime)/csound->esr;
       }
     }
@@ -1024,14 +1029,14 @@ int sensevents(CSOUND *csound)
     return 2;                   /* done with entire score */
 }
 
-static inline uint32 time2kcnt(CSOUND *csound, double tval)
+static inline uint64_t time2kcnt(CSOUND *csound, double tval)
 {
     if (tval > 0.0) {
       tval *= (double) csound->global_ekr;
 #ifdef HAVE_C99
-      return (uint32) llrint(tval);
+      return (uint64_t) llrint(tval);
 #else
-      return (uint32) (tval + 0.5);
+      return (uint64_t) (tval + 0.5);
 #endif
     }
     return 0UL;
@@ -1052,7 +1057,7 @@ static inline uint32 time2kcnt(CSOUND *csound, double tval)
 /* made.                                                              */
 /* Return value is zero on success.                                   */
 
-int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, long time_ofs)
+int insert_score_event_at_sample(CSOUND *csound, EVTBLK *evt, int64_t time_ofs)
 {
     double        start_time;
     EVTNODE       *e, *prv;
@@ -1216,9 +1221,6 @@ void musmon_rewind_score(CSOUND *csound)
         settempo(csound, (MYFLT) csound->oparms->cmdTempo);
       else
         settempo(csound, FL(60.0));
-      /* rewind score file */
-      if (csound->scfp != NULL)
-        fseek(csound->scfp, 0L, SEEK_SET);
       /* update section/overall amplitudes, reset to section 1 */
       section_amps(csound, 1);
       ST(sectno) = 1;
@@ -1229,6 +1231,8 @@ void musmon_rewind_score(CSOUND *csound)
     csound->advanceCnt = 0;
     if (csound->csoundScoreOffsetSeconds_ > FL(0.0))
       csound->SetScoreOffsetSeconds(csound, csound->csoundScoreOffsetSeconds_);
+
+    corfile_rewind(csound->scstr);
 }
 
 /**
@@ -1264,4 +1268,3 @@ PUBLIC int csoundRegisterSenseEventCallback(CSOUND *csound,
 
     return 0;
 }
-
