@@ -30,6 +30,7 @@
 #include "insert.h"
 #include "pstream.h"
 #include "namedins.h"           /* IV - Oct 31 2002 */
+#include "corfile.h"
 
 typedef struct NAME_ {
     char          *namep;
@@ -108,13 +109,13 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     OPCODINFO   *inm = (OPCODINFO*) opc->useropinfo;
     char    *types, *otypes;
     int     i, i_incnt, a_incnt, k_incnt, i_outcnt, a_outcnt, k_outcnt, err;
-    int     S_incnt, S_outcnt, f_outcnt, f_incnt;
+    int     S_incnt, S_outcnt, f_outcnt, f_incnt, t_incnt, t_outcnt;
     int16   *a_inlist, *k_inlist, *i_inlist, *a_outlist, *k_outlist, *i_outlist;
-    int16   *S_inlist, *S_outlist, *f_inlist, *f_outlist;
+    int16   *S_inlist, *S_outlist, *f_inlist, *f_outlist, *t_inlist, *t_outlist;
 
     /* count the number of arguments, and check types */
     i = i_incnt = S_incnt = a_incnt = k_incnt = f_incnt = f_outcnt =
-        i_outcnt = S_outcnt = a_outcnt = k_outcnt = err = 0;
+        i_outcnt = S_outcnt = a_outcnt = k_outcnt = t_incnt = t_outcnt = err = 0;
     types = inm->intypes; otypes = opc->intypes;
     opc->dsblksiz = (uint16) sizeof(UOPCODE);
     if (!strcmp(types, "0"))
@@ -132,6 +133,9 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'f':
         f_incnt++; *otypes++ = *types;
         break;
+      case 't':
+          t_incnt++; *otypes++ = *types;
+          break;
       case 'i':
       case 'o':
       case 'p':
@@ -153,7 +157,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes++ = 'o'; *otypes = '\0';    /* optional arg for local ksmps */
     inm->inchns = i;                    /* total number of input chnls */
-    inm->perf_incnt = a_incnt + k_incnt + f_incnt;
+    inm->perf_incnt = a_incnt + k_incnt + f_incnt + t_incnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     /* same for outputs */
     i = 0;
@@ -177,6 +181,9 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'f':
         f_outcnt++; *otypes++ = *types;
         break;
+      case 't':
+        t_outcnt++; *otypes++ = *types;
+        break;
       case 'i':
         i_outcnt++; *otypes++ = *types;
         break;
@@ -191,7 +198,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes = '\0';
     inm->outchns = i;                   /* total number of output chnls */
-    inm->perf_outcnt = a_outcnt + k_outcnt + f_outcnt;
+    inm->perf_outcnt = a_outcnt + k_outcnt + f_outcnt + t_outcnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     opc->dsblksiz = ((opc->dsblksiz + (uint16) 15)
                      & (~((uint16) 15)));   /* align (needed ?) */
@@ -199,17 +206,19 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     i = i_incnt + S_incnt + inm->perf_incnt +
         i_outcnt + S_outcnt + inm->perf_outcnt;
     i_inlist = inm->in_ndx_list = (int16*) mmalloc(csound,
-                                                   sizeof(int16) * (i + 10));
+                                                   sizeof(int16) * (i + 14));
     S_inlist = i_inlist + i_incnt + 1;
     a_inlist = S_inlist + S_incnt + 1;
     k_inlist = a_inlist + a_incnt + 1;
     f_inlist = k_inlist + k_incnt + 1;
+    t_inlist = f_inlist + f_incnt + 1;
     i = 0; types = inm->intypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_inlist++ = i; break;
         case 'k': *k_inlist++ = i; break;
         case 'f': *f_inlist++ = i; break;
+        case 't': *t_inlist++ = i; break;
         case 'K': *k_inlist++ = i;      /* also updated at i-time */
         case 'i':
         case 'o':
@@ -219,25 +228,28 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = -1;     /* put delimiters */
-    i_outlist = inm->out_ndx_list = f_inlist + 1;
+    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = *t_inlist = -1;     /* put delimiters */
+    i_outlist = inm->out_ndx_list = t_inlist + 1;
     S_outlist = i_outlist + i_outcnt + 1;
     a_outlist = S_outlist + S_outcnt + 1;
     k_outlist = a_outlist + a_outcnt + 1;
     f_outlist = k_outlist + k_outcnt + 1;
+    t_outlist = f_outlist + f_outcnt + 1;
     i = 0; types = inm->outtypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_outlist++ = i; break;
         case 'k': *k_outlist++ = i; break;
         case 'f': *f_outlist++ = i; break;
+        case 't': *t_outlist++ = i; break;
         case 'K': *k_outlist++ = i;     /* also updated at i-time */
         case 'i': *i_outlist++ = i; break;
         case 'S': *S_outlist++ = i; break;
       }
       i++;
     }
-    *i_outlist = *S_outlist = *a_outlist = *k_outlist = *f_outlist = -1;  /* put delimiters */
+    *i_outlist = *S_outlist = *a_outlist = *k_outlist =
+      *f_outlist = *t_outlist = -1;  /* put delimiters */
     return err;
 }
 
@@ -285,12 +297,12 @@ void otran(CSOUND *csound)
     gblnamset(csound, "$ksmps");
 
     rdorchfile(csound);         /* go read orch file    */
+    corfile_rm(&(csound->orchstr));
 
     csound->pool = (MYFLT*) mmalloc(csound, NCONSTS * sizeof(MYFLT));
     ST(poolcount) = 0;
     ST(nconsts) = NCONSTS;
     ST(constTbl) = (int*) mcalloc(csound, (256 + NCONSTS) * sizeof(int));
-    setlocale(LC_NUMERIC, "C"); /* Ensure C syntax */
     constndx(csound, "0");
 
     while ((tp = getoptxt(csound, &init)) != NULL) {
@@ -352,7 +364,8 @@ void otran(CSOUND *csound)
                     err++; continue;
                   }
                   /* IV - Oct 31 2002: store the name */
-                  if (UNLIKELY(!named_instr_alloc(csound, c, ip, insno_priority))) {
+                  if (UNLIKELY(!named_instr_alloc(csound, c, ip,
+                                                  insno_priority))) {
                     synterr(csound, Str("instr %s redefined"), c);
                     err++; continue;
                   }
@@ -568,7 +581,8 @@ void otran(CSOUND *csound)
       else if (UNLIKELY(p->tran_ksmps < FL(0.75) ||
                         FLOAT_COMPARE(p->tran_ksmps, MYFLT2LRND(p->tran_ksmps))))
         synterr(p, Str("%s invalid ksmps value"), err_msg);
-      else if (UNLIKELY(FLOAT_COMPARE(p->tran_sr, (double) p->tran_kr * p->tran_ksmps)))
+      else if (UNLIKELY(FLOAT_COMPARE(p->tran_sr,
+                                      (double) p->tran_kr * p->tran_ksmps)))
         synterr(p, Str("%s inconsistent sr, kr, ksmps"), err_msg);
     }
 
@@ -977,11 +991,15 @@ int lgexist(CSOUND *csound, const char *s)
     unsigned char h = name_hash(csound, s);
     NAME          *p;
 
+
+
     for (p = ST(gblNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
     if (p != NULL)
       return 1;
     for (p = ST(lclNames)[h]; p != NULL && sCmp(p->namep, s); p = p->nxt);
+
     return (p == NULL ? 0 : 1);
+
 }
 
 /* builds namelist & type counts for gbl names */
@@ -1424,7 +1442,7 @@ void oload(CSOUND *p)
     if (O->Beatmode && O->cmdTempo > 0) {
       /* if performing from beats, set the initial tempo */
       p->curBeat_inc = (double) O->cmdTempo / (60.0 * (double) p->ekr);
-      p->ibeatTime = (int)(p->esr*60.0 / (double) O->cmdTempo);
+      p->ibeatTime = (int64_t)(p->esr*60.0 / (double) O->cmdTempo);
     }
     else {
       p->curBeat_inc = 1.0 / (double) p->ekr;
@@ -1441,4 +1459,3 @@ void oload(CSOUND *p)
     if (UNLIKELY(init0(p) != 0))
       csoundDie(p, Str("header init errors"));
 }
-
