@@ -30,6 +30,7 @@
 #include "csound_orcparse.h"
 #include "insert.h"
 #include "namedins.h"
+#include "interlocks.h"
 
 #ifndef PARSER_DEBUG
 #define PARSER_DEBUG (0)
@@ -41,6 +42,8 @@ ORCTOKEN** symbtab;
 #define namedInstrFlag csound->parserNamedInstrFlag
 
 ORCTOKEN *add_token(CSOUND *csound, char *s, int type);
+static ORCTOKEN *add_token_p(CSOUND *csound, char *s, int type, int val);
+extern int csound_orcget_lineno(void*);
 
 int get_opcode_type(OENTRY *ep)
 {
@@ -136,10 +139,11 @@ void init_symbtab(CSOUND *csound)
     add_token(csound, "ampdbfs", T_FUNCTION);
     add_token(csound, "dbamp", T_FUNCTION);
     add_token(csound, "dbfsamp", T_FUNCTION);
-    add_token(csound, "ftlen", T_FUNCTION);
-    add_token(csound, "ftsr", T_FUNCTION);
-    add_token(csound, "ftlptim", T_FUNCTION);
-    add_token(csound, "ftchnls", T_FUNCTION);
+    add_token_p(csound, "ftcps", T_FUNCTION, TR);
+    add_token_p(csound, "ftlen", T_FUNCTION, TR);
+    add_token_p(csound, "ftsr", T_FUNCTION, TR);
+    add_token_p(csound, "ftlptim", T_FUNCTION, TR);
+    add_token_p(csound, "ftchnls", T_FUNCTION, TR);
     add_token(csound, "i", T_FUNCTION);
     add_token(csound, "k", T_FUNCTION);
     add_token(csound, "cpsoct", T_FUNCTION);
@@ -147,27 +151,27 @@ void init_symbtab(CSOUND *csound)
     add_token(csound, "cpspch", T_FUNCTION);
     add_token(csound, "pchoct", T_FUNCTION);
     add_token(csound, "octcps", T_FUNCTION);
-    add_token(csound, "nsamp", T_FUNCTION);
+    add_token_p(csound, "nsamp", T_FUNCTION, TR);
     add_token(csound, "powoftwo", T_FUNCTION);
     add_token(csound, "logbtwo", T_FUNCTION);
     add_token(csound, "a", T_FUNCTION);
-    add_token(csound, "tb0", T_FUNCTION);
-    add_token(csound, "tb1", T_FUNCTION);
-    add_token(csound, "tb2", T_FUNCTION);
-    add_token(csound, "tb3", T_FUNCTION);
-    add_token(csound, "tb4", T_FUNCTION);
-    add_token(csound, "tb5", T_FUNCTION);
-    add_token(csound, "tb6", T_FUNCTION);
-    add_token(csound, "tb7", T_FUNCTION);
-    add_token(csound, "tb8", T_FUNCTION);
-    add_token(csound, "tb9", T_FUNCTION);
-    add_token(csound, "tb10", T_FUNCTION);
-    add_token(csound, "tb11", T_FUNCTION);
-    add_token(csound, "tb12", T_FUNCTION);
-    add_token(csound, "tb13", T_FUNCTION);
-    add_token(csound, "tb14", T_FUNCTION);
-    add_token(csound, "tb15", T_FUNCTION);
-    add_token(csound, "urd", T_FUNCTION);
+    add_token_p(csound, "tb0", T_FUNCTION, TR);
+    add_token_p(csound, "tb1", T_FUNCTION, TR);
+    add_token_p(csound, "tb2", T_FUNCTION, TR);
+    add_token_p(csound, "tb3", T_FUNCTION, TR);
+    add_token_p(csound, "tb4", T_FUNCTION, TR);
+    add_token_p(csound, "tb5", T_FUNCTION, TR);
+    add_token_p(csound, "tb6", T_FUNCTION, TR);
+    add_token_p(csound, "tb7", T_FUNCTION, TR);
+    add_token_p(csound, "tb8", T_FUNCTION, TR);
+    add_token_p(csound, "tb9", T_FUNCTION, TR);
+    add_token_p(csound, "tb10", T_FUNCTION, TR);
+    add_token_p(csound, "tb11", T_FUNCTION, TR);
+    add_token_p(csound, "tb12", T_FUNCTION, TR);
+    add_token_p(csound, "tb13", T_FUNCTION, TR);
+    add_token_p(csound, "tb14", T_FUNCTION, TR);
+    add_token_p(csound, "tb15", T_FUNCTION, TR);
+    add_token_p(csound, "urd", T_FUNCTION, TR);
     add_token(csound, "not", T_FUNCTION);
     add_token(csound, "cent", T_FUNCTION);
     add_token(csound, "octave", T_FUNCTION);
@@ -175,6 +179,11 @@ void init_symbtab(CSOUND *csound)
     add_token(csound, "cpsmidinn", T_FUNCTION);
     add_token(csound, "octmidinn", T_FUNCTION);
     add_token(csound, "pchmidinn", T_FUNCTION);
+    add_token(csound, "db", T_FUNCTION);
+    add_token(csound, "p", T_FUNCTION);
+    add_token(csound, "qinf", T_FUNCTION);
+    add_token(csound, "qnan", T_FUNCTION);
+    add_token(csound, "##error", T_FUNCTION);
 }
 
 static unsigned int hash(char *s)
@@ -197,7 +206,7 @@ ORCTOKEN *add_token(CSOUND *csound, char *s, int type)
     while (a!=NULL) {
       if (strcmp(a->lexeme, s)==0) {
         if (type == a->type) return a;
-        if (type!= T_FUNCTION || a->type!=T_OPCODE) 
+        if (type!= T_FUNCTION || a->type!=T_OPCODE)
           csound->Warning(csound,
                           Str("Type confusion for %s (%d,%d), replacing\n"),
                           s, type, a->type);
@@ -216,12 +225,19 @@ ORCTOKEN *add_token(CSOUND *csound, char *s, int type)
     return ans;
 }
 
+static ORCTOKEN *add_token_p(CSOUND *csound, char *s, int type, int val)
+{
+    ORCTOKEN *ans = add_token(csound, s, type);
+    ans->value = val;
+    return ans;
+}
+
 int isUDOArgList(char *s)
 {
     int len = strlen(s) - 1;
 
     while (len >= 0) {
-      if (UNLIKELY(strchr("aijkKopS0", s[len]) == NULL)) {
+      if (UNLIKELY(strchr("aijkftKopS0", s[len]) == NULL)) {
         /* printf("Invalid char '%c' in '%s'", *p, s); */
         return 0;
       }
@@ -235,7 +251,7 @@ int isUDOAnsList(char *s)
     int len = strlen(s) - 1;
 
     while (len >= 0) {
-      if (UNLIKELY(strchr("aikSK0", s[len]) == NULL)) {
+      if (UNLIKELY(strchr("aikftSK0", s[len]) == NULL)) {
         return 0;
       }
       len--;
@@ -255,11 +271,11 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
 
     if (udoflag == 0) {
       if (isUDOAnsList(s)) {
-        ans = new_token(csound, T_UDO_ANS);
+        ans = new_token(csound, UDO_ANS_TOKEN);
         ans->lexeme = (char*)mmalloc(csound, 1+strlen(s));
         strcpy(ans->lexeme, s);
-        ans->next = symbtab[h];
-        symbtab[h] = ans;
+//        ans->next = symbtab[h];
+//        symbtab[h] = ans;
         //printf("Found UDO Answer List\n");
         return ans;
       }
@@ -267,11 +283,11 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
 
     if (udoflag == 1) {
       if (isUDOArgList(s)) {
-        ans = new_token(csound, T_UDO_ARGS);
+        ans = new_token(csound, UDO_ARGS_TOKEN);
         ans->lexeme = (char*)mmalloc(csound, 1+strlen(s));
         strcpy(ans->lexeme, s);
-        ans->next = symbtab[h];
-        symbtab[h] = ans;
+//        ans->next = symbtab[h];
+//        symbtab[h] = ans;
         //printf("Found UDO Arg List\n");
         return ans;
       }
@@ -289,7 +305,6 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
         ans->next = NULL;
         ans->lexeme = (char *)mmalloc(csound, strlen(a->lexeme) + 1);
         strcpy(ans->lexeme, a->lexeme);
-
         return ans;
       }
       a = a->next;
@@ -301,8 +316,8 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
     strcpy(ans->lexeme, s);
     //ans->next = symbtab[h];
 
-    if (PARSER_DEBUG)
-      csound->Message(csound, "NamedInstrFlag: %d\n", namedInstrFlag);
+    /* if (PARSER_DEBUG) */
+    /*   csound->Message(csound, "NamedInstrFlag: %d\n", namedInstrFlag); */
 
     if (udoflag == -2 || namedInstrFlag == 1) {
         return ans;
@@ -329,14 +344,14 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
       case 'w': type = T_IDENT_GW; break;
       case 't': type = T_IDENT_GT; break;
       case 'S': type = T_IDENT_GS; break;
-      default: 
-        csound->Message(csound, Str("Unknown word type for %s on line %d\n"),
-                        s, csound_orcget_lineno(yyscanner));
-        exit(1);
+      /* default:  */
+      /*   csound->Message(csound, Str("Unknown word type for %s on line %d\n"), */
+      /*                   s, csound_orcget_lineno(yyscanner)); */
+      /*   exit(1); */
       }
     default: /*
-      printf("IDENT Token: %i : %i", ans->type, T_IDENT);
-      printf("Unknown word type for %s on line %d\n", s, yyline);
+      csound->DebugMsg(csound,"IDENT Token: %i : %i", ans->type, T_IDENT);
+      csound->DebugMsg(csound,"Unknown word type for %s on line %d\n", s, yyline);
       exit(1);
              */
       break;
@@ -353,6 +368,7 @@ ORCTOKEN *lookup_token(CSOUND *csound, char *s, void *yyscanner)
 /* UDO code below was from otran, broken out and modified for new parser by
  * SYY
  */
+/* VL -- I have made the modifications below to allow for f-sigs & t-sigs and on line 224 and 238*/
 
 /* IV - Oct 12 2002: new function to parse arguments of opcode definitions */
 static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
@@ -360,13 +376,13 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     OPCODINFO   *inm = (OPCODINFO*) opc->useropinfo;
     char    *types, *otypes;
     int     i, i_incnt, a_incnt, k_incnt, i_outcnt, a_outcnt, k_outcnt, err;
-    int     S_incnt, S_outcnt;
+    int     S_incnt, S_outcnt, f_outcnt, f_incnt, t_incnt, t_outcnt;
     int16   *a_inlist, *k_inlist, *i_inlist, *a_outlist, *k_outlist, *i_outlist;
-    int16   *S_inlist, *S_outlist;
+    int16   *S_inlist, *S_outlist, *f_inlist, *f_outlist, *t_inlist, *t_outlist;
 
     /* count the number of arguments, and check types */
-    i = i_incnt = S_incnt = a_incnt = k_incnt =
-        i_outcnt = S_outcnt = a_outcnt = k_outcnt = err = 0;
+    i = i_incnt = S_incnt = a_incnt = k_incnt = f_incnt = f_outcnt =
+        i_outcnt = S_outcnt = a_outcnt = k_outcnt = t_incnt = t_outcnt = err = 0;
     types = inm->intypes; otypes = opc->intypes;
     opc->dsblksiz = (uint16) sizeof(UOPCODE);
     if (!strcmp(types, "0"))
@@ -381,6 +397,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'k':
         k_incnt++; *otypes++ = 'k';
         break;
+      case 'f':
+        f_incnt++; *otypes++ = *types;
+        break;
+      case 't':
+        t_incnt++; *otypes++ = *types;
+        break;
       case 'i':
       case 'o':
       case 'p':
@@ -402,7 +424,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes++ = 'o'; *otypes = '\0';    /* optional arg for local ksmps */
     inm->inchns = i;                    /* total number of input chnls */
-    inm->perf_incnt = a_incnt + k_incnt;
+    inm->perf_incnt = a_incnt + k_incnt + f_incnt + t_incnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     /* same for outputs */
     i = 0;
@@ -423,6 +445,12 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       case 'k':
         k_outcnt++; *otypes++ = 'k';
         break;
+      case 'f':
+        f_outcnt++; *otypes++ = *types;
+        break;
+      case 't':
+        t_outcnt++; *otypes++ = *types;
+        break;
       case 'i':
         i_outcnt++; *otypes++ = *types;
         break;
@@ -437,7 +465,7 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     }
     *otypes = '\0';
     inm->outchns = i;                   /* total number of output chnls */
-    inm->perf_outcnt = a_outcnt + k_outcnt;
+    inm->perf_outcnt = a_outcnt + k_outcnt + f_outcnt + t_outcnt;
     opc->dsblksiz += (uint16) (sizeof(MYFLT*) * i);
     opc->dsblksiz = ((opc->dsblksiz + (uint16) 15)
                      & (~((uint16) 15)));   /* align (needed ?) */
@@ -445,15 +473,19 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
     i = i_incnt + S_incnt + inm->perf_incnt +
         i_outcnt + S_outcnt + inm->perf_outcnt;
     i_inlist = inm->in_ndx_list = (int16*) mmalloc(csound,
-                                                   sizeof(int16) * (i + 8));
+                                                   sizeof(int16) * (i + 14));
     S_inlist = i_inlist + i_incnt + 1;
     a_inlist = S_inlist + S_incnt + 1;
     k_inlist = a_inlist + a_incnt + 1;
+    f_inlist = k_inlist + k_incnt + 1;
+    t_inlist = f_inlist + f_incnt + 1;
     i = 0; types = inm->intypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_inlist++ = i; break;
         case 'k': *k_inlist++ = i; break;
+        case 'f': *f_inlist++ = i; break;
+        case 't': *t_inlist++ = i; break;
         case 'K': *k_inlist++ = i;      /* also updated at i-time */
         case 'i':
         case 'o':
@@ -463,23 +495,31 @@ static int parse_opcode_args(CSOUND *csound, OENTRY *opc)
       }
       i++;
     }
-    *i_inlist = *S_inlist = *a_inlist = *k_inlist = -1;     /* put delimiters */
-    i_outlist = inm->out_ndx_list = k_inlist + 1;
+
+    /* put delimiters */
+    *i_inlist = *S_inlist = *a_inlist = *k_inlist = *f_inlist = *t_inlist = -1;
+    i_outlist = inm->out_ndx_list = t_inlist + 1;
     S_outlist = i_outlist + i_outcnt + 1;
     a_outlist = S_outlist + S_outcnt + 1;
     k_outlist = a_outlist + a_outcnt + 1;
+    f_outlist = k_outlist + k_outcnt + 1;
+    t_outlist = f_outlist + f_outcnt + 1;
     i = 0; types = inm->outtypes;
     while (*types) {
       switch (*types++) {
         case 'a': *a_outlist++ = i; break;
         case 'k': *k_outlist++ = i; break;
+        case 'f': *f_outlist++ = i; break;
+        case 't': *t_outlist++ = i; break;
         case 'K': *k_outlist++ = i;     /* also updated at i-time */
         case 'i': *i_outlist++ = i; break;
         case 'S': *S_outlist++ = i; break;
       }
       i++;
     }
-    *i_outlist = *S_outlist = *a_outlist = *k_outlist = -1;  /* put delimiters */
+
+    *i_outlist = *S_outlist = *a_outlist = *k_outlist =
+      *f_outlist = *t_outlist = -1;  /* put delimiters */
     return err;
 }
 
