@@ -55,7 +55,7 @@ void twarp(CSOUND *csound) /* time-warp a score section acc to T-statement */
     do {
       switch (bp->text[0]) {                /* else warp all timvals */
       case 'i':
-        if ((absp3 = bp->newp3) < 0) {
+        if (UNLIKELY((absp3 = bp->newp3) < 0)) {
           absp3 = -absp3;
           negp3++;
         }
@@ -148,7 +148,7 @@ int realtset(CSOUND *csound, SRTBLK *bp)
     tp->durslp = FL(0.0);                     /* clear last durslp */
     if (UNLIKELY(++tp > (TSEG*) csound->tplim))
       goto error3;
-    tp->betbas = FL(999999.9);                /* and cap with large betval */
+    tp->betbas = FL(9223372036854775807.0);   /* and cap with large betval */
     return(1);
 
  error1:
