@@ -214,7 +214,7 @@
 
 #if (defined(WIN32) || defined(_WIN32)) && !defined(SWIG)
 #  define PUBLIC        __declspec(dllexport)
-#elif defined(__GNUC__)
+#elif defined(__GNUC__) && !defined(__MACH__)
 #  define PUBLIC        __attribute__ ( (visibility("default")) )
 #else
 #  define PUBLIC
@@ -954,6 +954,9 @@ extern "C" {
     PUBLIC int csoundScoreEvent(CSOUND *,
             char type, const MYFLT *pFields, long numFields);
 
+    PUBLIC int csoundScoreEventAbsolute(CSOUND *,
+            char type, const MYFLT *pfields, long numFields, double time_ofs);
+
     /*
      * MIDI
      */
@@ -1400,25 +1403,6 @@ extern "C" {
 #  define CSOUND_SPIN_UNLOCK
 #endif
 
-#elif defined(__GNUC__) && defined(HAVE_PTHREAD_SPIN_LOCK)
-# if defined(SWIG)
-#define csoundSpinLock(spinlock)                        \
-  {                                                     \
-    pthread_spin_lock((pthread_spinlock_t *)spinlock);  \
-  }
-#define csoundSpinUnLock(spinlock)                       \
-  {                                                      \
-    pthread_spin_unlock((pthread_spinlock_t *)spinlock); \
-  }
-#  define CSOUND_SPIN_LOCK static int32_t spinlock = 0; csoundSpinLock(&spinlock);
-#  define CSOUND_SPIN_UNLOCK csoundSpinUnLock(&spinlock);
-# else
-#  define csoundSpinLock(spinlock)
-#  define csoundSpinUnLock(spinlock)
-#  define CSOUND_SPIN_LOCK
-#  define CSOUND_SPIN_UNLOCK
-#endif
-
 #elif defined(__GNUC__) && defined(HAVE_SYNC_LOCK_TEST_AND_SET)
 
 # define csoundSpinLock(spinlock)                               \
@@ -1434,17 +1418,17 @@ extern "C" {
 # define CSOUND_SPIN_UNLOCK csoundSpinUnLock(&spinlock);
 
 #elif defined(MACOSX)
-  
+
 #ifndef SWIG
 
 #include <libkern/OSAtomic.h>
-#define csoundSpinLock(spinlock)                        \
-    {                                                     \
-       OSSpinLockLock(spinlock);                          \
+#define csoundSpinLock(spinlock)                \
+    {                                           \
+       OSSpinLockLock(spinlock);                \
     }
 #define csoundSpinUnLock(spinlock)              \
-    {                                             \
-       OSSpinLockUnlock(spinlock);                \
+    {                                           \
+       OSSpinLockUnlock(spinlock);              \
     }
 #define CSOUND_SPIN_LOCK static int32_t spinlock = 0; csoundSpinLock(&spinlock);
 
@@ -1987,4 +1971,3 @@ extern "C" {
 #endif
 
 #endif  /* CSOUND_H */
-
