@@ -39,6 +39,9 @@
 %}
 #else
 #include "csound.h"
+#if defined(HAVE_PTHREAD_SPIN_LOCK) && !defined(SWIG)
+#include <pthread.h>
+#endif
 #ifdef __BUILDING_CSOUND_INTERFACES
 //#include "cs_glue.h"
 #endif
@@ -57,6 +60,42 @@ struct PUBLIC pycbdata {
 
 #if defined(__cplusplus)
 
+#if defined(HAVE_PTHREAD_SPIN_LOCK) && !defined(SWIG)
+struct Spinlock
+{
+    pthread_spinlock_t lock_;
+    Spinlock()
+    {
+        pthread_spin_init(&lock_, PTHREAD_PROCESS_PRIVATE);
+    }
+    ~Spinlock()
+    {
+        pthread_spin_destroy(&lock_);
+    }
+    void lock()
+    {
+        pthread_spin_lock(&lock_);
+    }
+    void unlock()
+    {
+        pthread_spin_unlock(&lock_);
+    }
+};
+
+struct Spinlocker
+{
+    Spinlock &spinlock;
+    Spinlocker(Spinlock &spinlock_) : spinlock(spinlock_)
+    {
+        spinlock.lock();
+    }
+    ~Spinlocker()
+    {
+        spinlock.unlock();
+    }
+};
+#endif
+
 
 /**
  * C++ interface to the "C" Csound API.
@@ -78,12 +117,10 @@ public:
   {
     return csoundPreCompile(csound);
   }
-#ifndef OLPC
   virtual int InitializeCscore(FILE *insco, FILE *outsco)
   {
     return csoundInitializeCscore(csound, insco, outsco);
   }
-#endif
   virtual void *GetHostData()
   {
     return csoundGetHostData(csound);
@@ -349,12 +386,10 @@ public:
   {
     csoundRewindScore(csound);
   }
-#ifndef OLPC
   virtual void SetCscoreCallback(void (*cscoreCallback_)(CSOUND *))
   {
     csoundSetCscoreCallback(csound, cscoreCallback_);
   }
-#endif
   virtual int ScoreSort(FILE *inFile, FILE *outFile)
   {
     return csoundScoreSort(csound, inFile, outFile);
@@ -419,6 +454,11 @@ public:
   {
     return csoundScoreEvent(csound, type, pFields, numFields);
   }
+  virtual int ScoreEventAbsolute(char type, const MYFLT *pFields,
+				 long numFields, double time_ofs)
+  {
+    return csoundScoreEventAbsolute(csound, type, pFields, numFields, time_ofs);
+  }
   // MIDI
   virtual void SetExternalMidiInOpenCallback(
       int (*func)(CSOUND *, void **, const char *))
@@ -772,6 +812,7 @@ public:
     csound = csoundCreate((CSOUND*) 0);
      #ifdef SWIGPYTHON
       pydata =(pycbdata *) new pycbdata;
+      memset(pydata, sizeof(pydata), 0);
     ((pycbdata *)pydata)->mfunc = NULL;
     ((pycbdata *)pydata)->messageBufferIndex = 0;
     csoundSetHostData(csound, this);
@@ -830,6 +871,22 @@ public:
   {
     return csoundGetSpoutSample(csound, frame, channel);
   }
+  virtual int ChanIKSetValue(int channel, MYFLT value)
+  {
+    return csoundChanIKSetValue(csound, channel, value);
+  }
+  virtual MYFLT ChanOKGetValue(int channel)
+  {
+    return  csoundChanOKGetValue(csound, channel);
+  }
+  virtual int ChanIASetSample(int channel, int frame, MYFLT sample)
+  {
+    return csoundChanIASetSample(csound, channel, frame, sample);
+  }
+  virtual MYFLT ChanOAGetSample(int channel, int frame)
+  {
+    return csoundChanOAGetSample(csound, channel, frame);
+  }
 };
 
 // thread locks
