@@ -55,6 +55,7 @@
 #include "bus.h"
 #include "pstream.h"
 #include "remote.h"
+#include "resize.h"
 #ifdef PARCS
 #include "cs_par_ops.h"
 #endif
@@ -168,7 +169,14 @@ int     itabl3(CSOUND *, void *), tabl3(CSOUND *, void *);
 int     ktabl3(CSOUND *, void *), tblset(CSOUND *, void *);
 int     ktable(CSOUND *, void *), ktabli(CSOUND *, void *);
 int     tabli(CSOUND *, void *), tablefn(CSOUND *, void *);
+int     pitable(CSOUND *, void *), pitabli(CSOUND *, void *);
+int     pitabl3(CSOUND *, void *), ptabl3(CSOUND *, void *);
+int     pktabl3(CSOUND *, void *), itblchkw(CSOUND *, void *);
+int     pktable(CSOUND *, void *), pktabli(CSOUND *, void *);
+int     ptabli(CSOUND *, void *), ptablefn(CSOUND *, void *);
 int     tblsetkt(CSOUND *, void *), ktablekt(CSOUND *, void *);
+int     pitablew(CSOUND *, void *), ptblsetw(CSOUND *, void *);
+int     pktablew(CSOUND *, void *), ptablew(CSOUND *, void *);
 int     tablekt(CSOUND *, void *), ktablikt(CSOUND *, void *);
 int     tablikt(CSOUND *, void *), ko1set(CSOUND *, void *);
 int     kosc1(CSOUND *, void *), kosc1i(CSOUND *, void *);
@@ -220,13 +228,14 @@ int     inq(CSOUND *, void *), inh(CSOUND *, void *);
 int     ino(CSOUND *, void *), in16(CSOUND *, void *);
 int     in32(CSOUND *, void *);
 int     inch_opcode(CSOUND *, void *), inall_opcode(CSOUND *, void *);
-int     out(CSOUND *, void *), outs(CSOUND *, void *);
+int     outmultiple(CSOUND *, void *);
+/* int     out(CSOUND *, void *), outs(CSOUND *, void *); */
 int     outs1(CSOUND *, void *), outs2(CSOUND *, void *);
-int     outq(CSOUND *, void *);
+/* int     outq(CSOUND *, void *); */
 int     outq1(CSOUND *, void *), outq2(CSOUND *, void *);
 int     outq3(CSOUND *, void *), outq4(CSOUND *, void *);
-int     outh(CSOUND *, void *), outo(CSOUND *, void *);
-int     outx(CSOUND *, void *), outX(CSOUND *, void *);
+/* int     outh(CSOUND *, void *), outo(CSOUND *, void *); */
+/* int     outx(CSOUND *, void *), outX(CSOUND *, void *); */
 int     outch(CSOUND *, void *), outall(CSOUND *, void *);
 int     igoto(CSOUND *, void *), kgoto(CSOUND *, void *);
 int     icgoto(CSOUND *, void *), kcgoto(CSOUND *, void *);
@@ -307,7 +316,7 @@ int     lp2_set(CSOUND *, void *), lp2(CSOUND *, void *);
 int     phaser2set(CSOUND *, void *), phaser2(CSOUND *, void *);
 int     phaser1set(CSOUND *, void *), phaser1(CSOUND *, void *);
 int     balnset(CSOUND *, void *), balance(CSOUND *, void *);
-int     prealloc(CSOUND *, void *);
+int     prealloc(CSOUND *, void *), active_alloc(CSOUND*, void*);
 int     cpsxpch(CSOUND *, void *), cps2pch(CSOUND *, void *);
 int     cpstmid(CSOUND *, void *);
 int     cpstun(CSOUND *, void *), cpstun_i(CSOUND *, void *);
@@ -371,7 +380,7 @@ int     setksmpsset(CSOUND *, void *);
 int     xinset(CSOUND *, void *), xoutset(CSOUND *, void *);
 int     ingoto(CSOUND *, void *), kngoto(CSOUND *, void *);
 int     iingoto(CSOUND *, void *), kingoto(CSOUND *, void *);
-int     nstrnumset(CSOUND *, void *), turnoff2(CSOUND *, void *);
+int     nstrnumset(CSOUND *, void *), turnoff2k(CSOUND *, void *),  turnoff2S(CSOUND *, void *) ;
 int     loop_l_i(CSOUND *, void *), loop_le_i(CSOUND *, void *);
 int     loop_g_i(CSOUND *, void *), loop_ge_i(CSOUND *, void *);
 int     loop_l_p(CSOUND *, void *), loop_le_p(CSOUND *, void *);
@@ -392,3 +401,5 @@ int     kgaussi(CSOUND *, void *), agaussi(CSOUND *, void *);
 int     lsgset_bkpt(CSOUND *csound, void *p);
 int     xsgset_bkpt(CSOUND *csound, void *p);
 int     xsgset_bkpt(CSOUND *csound, void *p), xsgset2b(CSOUND *, void *);
+int     resize_table(CSOUND *csound, void *p);
+int     error_fn(CSOUND *csound, void *p);
