@@ -24,6 +24,7 @@
 #if defined(__BUILDING_LIBCSOUND) && !defined(_CSOUND_PROTO_H)
 #define _CSOUND_PROTO_H
 
+#include <sndfile.h>
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -56,7 +57,8 @@ void    reverbinit(CSOUND *);
 void    dispinit(CSOUND *);
 int     init0(CSOUND *);
 void    scsort(CSOUND *, FILE *, FILE *);
-int     scxtract(CSOUND *, FILE *, FILE *, FILE *);
+void    scsortstr(CSOUND *, CORFIL *);
+int     scxtract(CSOUND *, CORFIL *, FILE *);
 int     rdscor(CSOUND *, EVTBLK *);
 int     musmon(CSOUND *);
 void    RTLineset(CSOUND *);
@@ -71,7 +73,7 @@ int     sfsampsize(int sf_format);
 char    *type2string(int type);
 int     type2csfiletype(int type, int encoding);
 int     sftype2csfiletype(int type);
-void    rewriteheader(SNDFILE *ofd);
+void    rewriteheader(void *ofd);
 int     readOptions(CSOUND *, FILE *, int);
 int     argdecode(CSOUND *, int, char **);
 void    remove_tmpfiles(CSOUND *);
@@ -91,7 +93,7 @@ int     getsndin(CSOUND *, void *, MYFLT *, int, void *);
 void    *sndgetset(CSOUND *, void *);
 void    dbfs_init(CSOUND *, MYFLT dbfs);
 int     csoundLoadExternals(CSOUND *);
-SNDMEMFILE  *csoundLoadSoundFile(CSOUND *, const char *name, SF_INFO *sfinfo);
+SNDMEMFILE  *csoundLoadSoundFile(CSOUND *, const char *name, void *sfinfo);
 int     PVOCEX_LoadFile(CSOUND *, const char *fname, PVOCEX_MEMFILE *p);
 void    print_opcodedir_warning(CSOUND *);
 int     check_rtaudio_name(char *fName, char **devName, int isOutput);
@@ -101,7 +103,7 @@ int     csoundCheckOpcodePluginFile(CSOUND *, const char *);
 int     csoundLoadAllPluginOpcodes(CSOUND *);
 int     csoundLoadAndInitModule(CSOUND *, const char *);
 void    csoundNotifyFileOpened(CSOUND *, const char *, int, int, int);
-int     insert_score_event_at_sample(CSOUND *, EVTBLK *, long);
+int     insert_score_event_at_sample(CSOUND *, EVTBLK *, int64_t);
 
 /**
  * Register a function to be called at note deactivation.
