@@ -21,6 +21,9 @@
   02111-1307 USA
 */
 
+/* this code is deprecated, has been substituted by the rtauhal.c module */
+
+
 #include <CoreAudio.h>
 #include <unistd.h>
 #include <stdint.h>
@@ -45,7 +48,11 @@ typedef struct devparams_ {
     float   srate;
     int     nchns;
     int     isNInterleaved;
+#if defined(MAC_OS_X_VERSION_10_5) && (MAC_OS_X_VERSION_MIN_REQUIRED>=MAC_OS_X_VERSION_10_5)
     AudioDeviceIOProcID     procID;
+#else
+  int procID;
+#endif
 } DEVPARAMS;
 
 /* module interface functions */
