@@ -25,7 +25,9 @@
 /*                                              RTPA.C for PortAudio    */
 
 #include "csdl.h"
+#if !defined(WIN32)
 #include "soundio.h"
+#endif
 #include <portaudio.h>
 
 #define NO_FULLDUPLEX_PA_LOCK   0
@@ -62,8 +64,9 @@ typedef struct PA_BLOCKING_STREAM_ {
     PaStreamParameters outputPaParameters;
 #ifdef WIN32
     int         paused;                 /* VL: to allow for smooth pausing  */
-    int         paLockTimeout;
 #endif
+    int         paLockTimeout;
+    int         complete;
 } PA_BLOCKING_STREAM;
 
 static int pa_PrintErrMsg(CSOUND *csound, const char *fmt, ...)
@@ -280,7 +283,7 @@ static int paBlockingReadWriteOpen(CSOUND *csound)
 #endif
       csound->WaitThreadLock(pabs->paLock, (size_t) 500);
     csound->WaitThreadLock(pabs->clientLock, (size_t) 500);
-#ifdef WIN32
+
     pabs->paLockTimeout =
         (int) (1.33 * (pabs->outputPaParameters.suggestedLatency
                          >= pabs->inputPaParameters.suggestedLatency ?
@@ -290,7 +293,7 @@ static int paBlockingReadWriteOpen(CSOUND *csound)
       pabs->paLockTimeout = 25;
     else if (pabs->paLockTimeout > 1000)
       pabs->paLockTimeout = 1000;
-#endif
+
 
     err = Pa_OpenStream(&stream,
                         (pabs->mode & 1 ? &(pabs->inputPaParameters)
@@ -352,30 +355,35 @@ static int paBlockingReadWriteStreamCallback(const void *input,
     float   *paInput = (float*) input;
     float   *paOutput = (float*) output;
 
-    if (pabs->paStream == NULL
-#ifdef WIN32
-        || pabs->paused
-#endif
-        ) {
-      if (pabs->mode & 2)
-        paClearOutputBuffer(pabs, paOutput);
-      return paContinue;
+
+    if (pabs->complete == 1) {
+        return paComplete;
     }
 
+#ifdef WIN32
+if (pabs->paStream == NULL
+      || pabs->paused
+) {
+if (pabs->mode & 2)
+        paClearOutputBuffer(pabs, paOutput);
+return paContinue;
+}
+#endif
+
 #if NO_FULLDUPLEX_PA_LOCK
     err = 0;
     if (!pabs->noPaLock)
 #endif
-#ifndef __MACH__
-#  ifdef WIN32
+      /*#ifndef __MACH__*/
+      /*#  ifdef WIN32 */
       err = csound->WaitThreadLock(pabs->paLock, (size_t) pabs->paLockTimeout);
-#  else
-      err = csound->WaitThreadLock(pabs->paLock, (size_t) 500);
+    /*#  else
+    err = csound->WaitThreadLock(pabs->paLock, (size_t) 500);
 #  endif
-#else
+    #else
       csound->WaitThreadLock(pabs->paLock, (size_t) 500);
-    err = 0;
-#endif
+      err = 0;
+     #endif*/
 
     if (pabs->mode & 1) {
       int n = pabs->inBufSamples;
@@ -400,7 +408,8 @@ static int paBlockingReadWriteStreamCallback(const void *input,
       }
     }
 
-    csound->NotifyThreadLock(pabs->clientLock);
+   paClearOutputBuffer(pabs, pabs->outputBuffer);
+   csound->NotifyThreadLock(pabs->clientLock);
 
     return paContinue;
 }
@@ -489,6 +498,8 @@ static int recopen_(CSOUND *csound, const csRtAudioParams *parm)
     memcpy(&(pabs->inParm), parm, sizeof(csRtAudioParams));
     *(p->GetRtRecordUserData(p)) = (void*) pabs;
 
+    pabs->complete = 0;
+
     return 0;
 }
 
@@ -511,6 +522,8 @@ static int playopen_(CSOUND *csound, const csRtAudioParams *parm)
     memcpy(&(pabs->outParm), parm, sizeof(csRtAudioParams));
     *(p->GetRtPlayUserData(p)) = (void*) pabs;
 
+    pabs->complete = 0;
+
     return (paBlockingReadWriteOpen(p));
 }
 
@@ -519,12 +532,13 @@ static int playopen_(CSOUND *csound, const csRtAudioParams *parm)
 static void rtclose_(CSOUND *csound)
 {
     PA_BLOCKING_STREAM *pabs;
-
     pabs = (PA_BLOCKING_STREAM*) csound->QueryGlobalVariable(csound,
                                                              "_rtpaGlobals");
     if (pabs == NULL)
       return;
 
+    pabs->complete = 1;
+
     if (pabs->paStream != NULL) {
       PaStream  *stream = pabs->paStream;
       int       i;
@@ -535,11 +549,12 @@ static void rtclose_(CSOUND *csound)
 #endif
           csound->NotifyThreadLock(pabs->paLock);
         csound->NotifyThreadLock(pabs->clientLock);
-        Pa_Sleep(80);
+//        Pa_Sleep(80);
       }
-      Pa_AbortStream(stream);
+
+      Pa_StopStream(stream);
       Pa_CloseStream(stream);
-      Pa_Sleep(80);
+//      Pa_Sleep(80);
     }
 
     if (pabs->clientLock != NULL) {
@@ -818,4 +833,3 @@ PUBLIC int csoundModuleInfo(void)
 {
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int) sizeof(MYFLT));
 }
-
