@@ -74,13 +74,12 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
                                     "FLTK_Flags") == (void*) 0) {
       if (csound->CreateGlobalVariable(csound,
                                        "FLTK_Flags", sizeof(int)) != 0)
-        csound->Die(csound,
+        csound->Die(csound, "%s",
                     Str("widgets.cpp: error allocating FLTK flags"));
       initFlags = 1;
     }
     fltkFlags = getFLTKFlagsPtr(csound);
-    if (csound->oparms->displays &&
-        ((*fltkFlags) & 2) == 0 &&
+    if (((*fltkFlags) & 2) == 0 &&
         !(csound->oparms->graphsoff || csound->oparms->postscript)) {
 #ifdef LINUX
       Display *dpy = XOpenDisplay(NULL);
@@ -103,8 +102,8 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
           csound->SetKillXYinCallback(csound, KillXYin_FLTK);
            /* seemed to crash, but not anymore... */
           csound->RegisterResetCallback(csound, NULL, widget_reset);
-	  csound->Message(csound, "graph init \n");
-         
+          csound->Message(csound, "graph init \n");
+
         }
 #ifdef LINUX
       }
@@ -116,7 +115,7 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
 #endif
         (*fltkFlags) |= 28;
     }
-    if (!((*fltkFlags) & 129)) {
+    if (!((*fltkFlags) & 129))
       for ( ; ep->opname != NULL; ep++) {
         if (csound->AppendOpcode(csound, ep->opname,
                                  (int)ep->dsblksiz, (int)ep->thread,
@@ -127,7 +126,6 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
           return -1;
         }
       }
-    }
     else if (!((*fltkFlags) & 128)) {
       for ( ; ep->opname != NULL; ep++) {
         if (csound->AppendOpcode(
@@ -143,7 +141,8 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
       }
     }
 
-    widget_init(csound);
+    if (!(csound->oparms->graphsoff || csound->oparms->postscript))
+      widget_init(csound);
     return 0;
 }
 
@@ -151,4 +150,3 @@ PUBLIC int csoundModuleInfo(void)
 {
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int)sizeof(MYFLT));
 }
-
