@@ -27,6 +27,8 @@
 #include <math.h>
 #include <time.h>
 
+#define POW2TABSIZI 4096
+#define POW2MAX   24.0
 #define EIPT3       (25.0/3.0)
 #define LOGTWO      (0.69314718055994530942)
 #define STEPS       (32768)
@@ -35,26 +37,49 @@
 #define MIDINOTE0   (3.00)  /* Lowest midi note is 3.00 in oct & pch formats */
 
 /* static lookup tables, initialised once at start-up; also used by midi ops */
-MYFLT   cpsocfrc[OCTRES] = { FL(0.0) };
-static  MYFLT   powerof2[4096];
+/* MYFLT   cpsocfrc[OCTRES] = { FL(0.0) }; */
+/* static  MYFLT   powerof2[POW2TABSIZI]; */
 
 /* initialise the tables, called by csoundInitialize() */
 
-void aops_init_tables(void)
+/*void aops_init_tables(void)
 {
     int   i;
     for (i = 0; i < OCTRES; i++)
       cpsocfrc[i] = POWER(FL(2.0), (MYFLT)i / OCTRES) * ONEPT;
-    for (i = 0; i < 4096; i++)
-      powerof2[i] = POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/4096.0) - FL(15.0));
+    for (i = 0; i < POW2TABSIZI; i++)
+      powerof2[i] = POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
+}*/
+
+/* initialise the tables, called by csoundPreCompile() */
+void csound_aops_init_tables(CSOUND *csound)
+{
+    int   i;
+    if(csound->cpsocfrc==NULL)csound->cpsocfrc = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT)*OCTRES);
+    if(csound->powerof2==NULL) csound->powerof2 = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT)*POW2TABSIZI);
+    for (i = 0; i < OCTRES; i++)
+      csound->cpsocfrc[i] = POWER(FL(2.0), (MYFLT)i / OCTRES) * ONEPT;
+    for (i = 0; i < POW2TABSIZI; i++)
+      csound->powerof2[i] = POWER(FL(2.0), (MYFLT)i * (MYFLT)(1.0/POW2TABSIZI) - FL(POW2MAX));
 }
 
-static inline MYFLT pow2(MYFLT a)
-{
-    int n = (int)MYFLT2LRND(a * FL(4096.0)) + 61440;   /* 4096 * 15 */
-    return ((MYFLT) (1 << (n >> 12)) * powerof2[n & 4095]);
+
+MYFLT csoundPow2(CSOUND *csound, MYFLT a){
+
+  if(a > POW2MAX) a = POW2MAX;
+  else if(a < -POW2MAX) a = -POW2MAX;
+    int n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;   /* 4096 * 15 */
+    return ((MYFLT) (1UL << (n >> 12)) * csound->powerof2[n & (POW2TABSIZI-1)]);
+
 }
 
+
+/*static inline MYFLT pow2(MYFLT a)
+{
+    int n = (int)MYFLT2LRND(a * FL(POW2TABSIZI)) + POW2MAX*POW2TABSIZI;
+    return ((MYFLT) (1 << (n >> 12)) * powerof2[n & (POW2TABSIZI-1)]);
+}*/
+
 int rassign(CSOUND *csound, ASSIGN *p)
 {
     /* already assigned by otran */
@@ -137,7 +162,7 @@ typedef struct {
     OPDS    h;
     TABDAT  *tab;
 } TABDEL;
-  
+
 static int tabdel(CSOUND *csound, void *p)
 {
     TABDAT *t = ((TABDEL*)p)->tab;
@@ -152,7 +177,7 @@ int tinit(CSOUND *csound, INITT *p)
     MYFLT val = *p->value;
     TABDAT *t = p->a;
     int i;
- 
+
     t->size = size;
     mfree(csound, t->data);
     t->data = mmalloc(csound, sizeof(MYFLT)*(size+1));
@@ -170,7 +195,7 @@ int tassign(CSOUND *csound, ASSIGNT *p)
 {
     TABDAT *t = p->tab;
     int ind = MYFLT2LRND(*p->ind);
-    if (ind<0 || ind>t->size) 
+    if (ind<0 || ind>t->size)
       return csound->PerfError(csound,
                                Str("Index %d out of range [0,%d] in t[]\n"),
                                ind, t->size);
@@ -181,7 +206,7 @@ int tassign(CSOUND *csound, ASSIGNT *p)
 int tabref_check(CSOUND *csound, TABREF *p)
 {
     if (UNLIKELY(p->tab->data==NULL))
-      return csound->InitError(csound, Str("Vector notinitialised\n"));
+      return csound->InitError(csound, Str("Vector not initialised\n"));
     return OK;
 }
 
@@ -189,7 +214,7 @@ int tabref(CSOUND *csound, TABREF *p)
 {
     int ind = MYFLT2LRND(*p->ind);
     TABDAT *t = p->tab;
-     if (ind<0 || ind>t->size) 
+     if (ind<0 || ind>t->size)
       return csound->PerfError(csound,
                                Str("Index %d out of range [0,%d] in t[]\n"),
                                ind, t->size);
@@ -956,7 +981,7 @@ int logbasetwo_set(CSOUND *csound, EVAL *p)
 
 int powoftwo(CSOUND *csound, EVAL *p)
 {
-    *p->r = pow2(*p->a);
+    *p->r = csound->Pow2(csound,*p->a);
     return OK;
 }
 
@@ -964,7 +989,7 @@ int powoftwoa(CSOUND *csound, EVAL *p)
 {                                   /* by G.Maldonado, liberalised by JPff */
     int n, nsmps = csound->ksmps;
     for (n = 0; n < nsmps; n++)
-      p->r[n] = pow2(p->a[n]);
+      p->r[n] = csound->Pow2(csound,p->a[n]);
     return OK;
 }
 
@@ -974,7 +999,7 @@ int powoftwoa(CSOUND *csound, EVAL *p)
 int semitone(CSOUND *csound, EVAL *p)
 {
     MYFLT a = *p->a*ONEd12;
-    *p->r = pow2(a);
+    *p->r = csound->Pow2(csound,a);
     return OK;
 }
 
@@ -987,7 +1012,7 @@ int asemitone(CSOUND *csound, EVAL *p)            /* JPff */
     r = p->r;
     for (n=0; n<nsmps; n++) {
       MYFLT aa = (a[n])*ONEd12;
-      r[n] = pow2(aa);
+      r[n] = csound->Pow2(csound,aa);
     }
     return OK;
 }
@@ -995,7 +1020,7 @@ int asemitone(CSOUND *csound, EVAL *p)            /* JPff */
 int cent(CSOUND *csound, EVAL *p)
 {
     MYFLT a = *p->a*ONEd1200;
-    *p->r = pow2(a);
+    *p->r = csound->Pow2(csound,a);
     return OK;
 }
 
@@ -1008,7 +1033,7 @@ int acent(CSOUND *csound, EVAL *p)        /* JPff */
     r = p->r;
     for (n=0; n<nsmps; n++) {
       MYFLT aa = (a[n])*ONEd1200;
-      r[n] = pow2(aa);
+      r[n] = csound->Pow2(csound,aa);
   }
   return OK;
 }
@@ -1017,7 +1042,7 @@ int acent(CSOUND *csound, EVAL *p)        /* JPff */
 
 int db(CSOUND *csound, EVAL *p)
 {
-    *p->r = pow2(*p->a*LOG2_10D20);
+    *p->r = csound->Pow2(csound,*p->a*LOG2_10D20);
     return OK;
 }
 
@@ -1030,7 +1055,7 @@ int dba(CSOUND *csound, EVAL *p)          /* JPff */
     r = p->r;
     for (n=0; n<nsmps; n++) {
       MYFLT aa = a[n];
-      r[n] = pow2(aa*LOG2_10D20);
+      r[n] = csound->Pow2(csound,aa*LOG2_10D20);
     }
     return OK;
 }
@@ -1246,6 +1271,7 @@ int inall_opcode(CSOUND *csound, INALL *p)
     return OK;
 }
 
+#if 0
 int out(CSOUND *csound, OUTM *p)
 {
     int n;
@@ -1317,6 +1343,7 @@ int outq(CSOUND *csound, OUTQ *p)
     CSOUND_SPOUT_SPINUNLOCK
     return OK;
 }
+#endif
 
 int outs1(CSOUND *csound, OUTM *p)
 {
@@ -1488,6 +1515,7 @@ int outq4(CSOUND *csound, OUTM *p)
     return OK;
 }
 
+#if 0
 int outh(CSOUND *csound, OUTH *p)
 {
     MYFLT *sp = csound->spout, *ap1 = p->asig1, *ap2 = p->asig2, *ap3 = p->asig3,
@@ -1558,6 +1586,7 @@ int outo(CSOUND *csound, OUTO *p)
     CSOUND_SPOUT_SPINUNLOCK
     return OK;
 }
+#endif
 
 static int outn(CSOUND *csound, int n, OUTX *p)
 {
@@ -1588,6 +1617,7 @@ static int outn(CSOUND *csound, int n, OUTX *p)
     return OK;
 }
 
+#if 0
 int outx(CSOUND *csound, OUTX *p)
 {
     return outn(csound, 16, p);
@@ -1597,6 +1627,7 @@ int outX(CSOUND *csound, OUTX *p)
 {
     return outn(csound, 32, p);
 }
+#endif
 
 int outall(CSOUND *csound, OUTX *p)             /* Output a list of channels */
 {
@@ -1773,7 +1804,7 @@ int is_NaNa(CSOUND *csound, ASSIGN *p)
     int k, nsmps = csound->ksmps;
     MYFLT *a = p->a;
     *p->r = FL(0.0);
-    for (k=0; k<nsmps; k++) 
+    for (k=0; k<nsmps; k++)
       *p->r += isnan(a[k]);
     return OK;
 }
@@ -1798,3 +1829,8 @@ int is_infa(CSOUND *csound, ASSIGN *p)
     *p->r = ans*sign;
     return OK;
 }
+
+int error_fn(CSOUND *csound, ERRFN *p)
+{
+    return csound->InitError(csound, Str("Unknown functuon called"));
+}
