@@ -27,6 +27,7 @@
 #include "oload.h"
 #include "insert.h"     /* for goto's */
 #include "aops.h"       /* for cond's */
+extern int32 strarg2insno(CSOUND *, void *p, int is_string);
 
 int igoto(CSOUND *csound, GOTO *p)
 {
@@ -70,6 +71,7 @@ int kngoto(CSOUND *csound, CGOTO *p)
     return OK;
 }
 
+#ifdef VARGS
 /* an i-rate version that ALWAYS jumps at p-time */
 
 int iingoto(CSOUND *csound, CGOTO *p)
@@ -84,6 +86,7 @@ int kingoto(CSOUND *csound, CGOTO *p)
     csound->pds = p->lblblk->prvp;
     return OK;
 }
+#endif
 
 int timset(CSOUND *csound, TIMOUT *p)
 {
@@ -166,16 +169,19 @@ int turnoff(CSOUND *csound, LINK *p)    /* terminate the current instrument  */
 }
 
 /* turnoff2 opcode */
-
-int turnoff2(CSOUND *csound, TURNOFF2 *p)
+int turnoff2(CSOUND *csound, TURNOFF2 *p, int isStringArg)
 {
     MYFLT p1;
     INSDS *ip, *ip2, *nip;
     int   mode, insno, allow_release;
 
-    if (*(p->kInsNo) <= FL(0.0))
+    if(isStringArg){
+     p1 = (MYFLT) strarg2insno(csound, p->kInsNo, (p->XSTRCODE & 1));
+    } else p1 = *(p->kInsNo);
+
+    if (p1 <= FL(0.0))
       return OK;    /* not triggered */
-    p1 = *(p->kInsNo);
+
     insno = (int) p1;
     if (UNLIKELY(insno < 1 || insno > (int) csound->maxinsno ||
                  csound->instrtxtp[insno] == NULL)) {
@@ -233,6 +239,14 @@ int turnoff2(CSOUND *csound, TURNOFF2 *p)
     return OK;
 }
 
+int turnoff2S(CSOUND *csound, TURNOFF2 *p){
+  return turnoff2(csound, p, 1);
+}
+
+int turnoff2k(CSOUND *csound, TURNOFF2 *p){
+   return turnoff2(csound, p, 0);
+}
+
 int loop_l_i(CSOUND *csound, LOOP_OPS *p)
 {
     /* if ((indxvar += iincr) < ilimit) igoto l */
@@ -304,4 +318,3 @@ int loop_ge_p(CSOUND *csound, LOOP_OPS *p)
       csound->pds = p->l->prvp;
     return OK;
 }
-
