@@ -42,9 +42,7 @@ int fsigs_equal(const PVSDAT *f1, const PVSDAT *f2)
         && (f1->wintype == f2->wintype) /* harsh, maybe... */
         && (f1->N       == f2->N)
         && (f1->format  == f2->format)
-#ifndef OLPC
         && (f1->sliding == f2->sliding)
-#endif
         )
       return 1;
     return 0;
@@ -60,13 +58,11 @@ int fassign(CSOUND *csound, FASSIGN *p)
     float *fout,*fsrc;
     if (UNLIKELY(!fsigs_equal(p->fout,p->fsrc)))
       csound->Die(csound, Str("fsig = : formats are different.\n"));
-#ifndef OLPC
     if (p->fsrc->sliding) {
       memcpy(p->fout->frame.auxp, p->fsrc->frame.auxp,
              sizeof(MYFLT)*(p->fsrc->N+2)*csound->ksmps);
       return OK;
     }
-#endif
     fout = (float *) p->fout->frame.auxp;
     fsrc = (float *) p->fsrc->frame.auxp;
 
@@ -88,10 +84,8 @@ int pvadsynset(CSOUND *csound, PVADS *p)
     int32 startbin,binoffset;
     MYFLT *p_x;
 
-#ifndef OLPC
     if (UNLIKELY(p->fsig->sliding))
       csound->InitError(csound, Str("Sliding version not yet available"));
-#endif
     p->overlap = p->fsig->overlap;
     /* a moot question, whether window params are relevant for adsyn?*/
     /* but for now, we validate all params in fsig */
@@ -113,7 +107,7 @@ int pvadsynset(CSOUND *csound, PVADS *p)
     /* check bin params */
     startbin = (int32) *p->ibin;            /* default 0 */
     binoffset = (int32) *p->ibinoffset; /* default 1 */
-    if (UNLIKELY(startbin        < 0 || startbin > noscs))
+    if (UNLIKELY(startbin < 0 || startbin > noscs))
       csound->Die(csound, Str("pvsadsyn: ibin parameter out of range.\n"));
     if (UNLIKELY(startbin + n_oscs > noscs))
       csound->Die(csound, Str("pvsadsyn: ibin + inoscs too large.\n"));
@@ -164,7 +158,7 @@ static void adsyn_frame(CSOUND *csound, PVADS *p)
     float *frame;        /* RWD MUST be 32bit */
     MYFLT *a,*x,*y;
     MYFLT *amps,*freqs,*lastamps;
-    MYFLT ffac = *p->kfmod;
+    MYFLT ffac    = *p->kfmod;
     MYFLT nyquist = csound->esr * FL(0.5);
     /* we add to outbuf, so clear it first*/
     memset(p->outbuf.auxp,0,p->overlap * sizeof(MYFLT));
@@ -256,7 +250,6 @@ int pvscrosset(CSOUND *csound, PVSCROSS *p)
     p->fout->winsize = p->winsize;
     p->fout->wintype = p->wintype;
     p->fout->format = p->format;
-#ifndef OLPC
     p->fout->format = p->fsrc->sliding;
     if (p->fsrc->sliding) {
       p->fout->NB = p->fsrc->NB;
@@ -264,7 +257,6 @@ int pvscrosset(CSOUND *csound, PVSCROSS *p)
                        &p->fout->frame);
       return OK;
     }
-#endif
     /* setup output signal */
     /* RWD MUST be 32bit */
     csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
@@ -290,7 +282,6 @@ int pvscross(CSOUND *csound, PVSCROSS *p)
       csound->Die(csound, Str("pvscross: mismatch in fsrc format\n"));
     if (UNLIKELY(!fsigs_equal(p->fout,p->fdest)))
       csound->Die(csound, Str("pvscross: mismatch in fdest format\n"));
-#ifndef OLPC
     if (p->fsrc->sliding) {
       CMPLX *fout, *fsrc, *fdest;
       int n, nsmps = csound->ksmps;
@@ -307,7 +298,6 @@ int pvscross(CSOUND *csound, PVSCROSS *p)
       }
       return OK;
    }
-#endif
     /* only process when a new frame is ready */
     if (p->lastframe < p->fsrc->framecount) {
 #ifdef _DEBUG
@@ -346,10 +336,8 @@ int pvsfreadset(CSOUND *csound, PVSFREAD *p)
     p->arate   = csound->esr / (MYFLT) pp.overlap;
     p->membase = (float*) pp.data;
 
-#ifndef OLPC
     if (UNLIKELY(p->overlap < csound->ksmps || p->overlap < 10))
       csound->InitError(csound, Str("Sliding version not yet available"));
-#endif
     if (UNLIKELY(p->nframes <= 0))
       csound->Die(csound, Str("pvsfread: file is empty!\n"));
     /* special case if only one frame - it is an impulse response */
@@ -405,16 +393,17 @@ int pvsfread(CSOUND *csound, PVSFREAD *p)
     n_mcframes = p->nframes / p->chans;
 
     if (p->ptr>=p->overlap) {
-      if (UNLIKELY(pos < 0.0f))
-        pos = 0.0f;     /* or report as error... */
+      if (UNLIKELY(pos < FL(0.0)))
+        pos = FL(0.0);     /* or report as error... */
       framepos = pos * p->arate;
       frame1pos = (int32) framepos;
 
       if (frame1pos>= n_mcframes -1) {
         /* just return final frame */
         pframe1 = pmem + (p->blockalign * (n_mcframes -1)) + p->chanoffset;
-        for (i=0;i < framesize;i++)
-          *fout++ = *pframe1++;
+        /* for (i=0;i < framesize;i++) */
+        /*   *fout++ = *pframe1++; */
+        memcpy(fout, pframe1, sizeof(float)*framesize);
       }
       else {
         /* gotta interpolate */
@@ -426,9 +415,9 @@ int pvsfread(CSOUND *csound, PVSFREAD *p)
         pframe2 = pframe1 + p->blockalign;
         for (i=0;i < framesize;i+=2) {
           MYFLT amp,freq;
-          j = i+1;
-          amp = pframe1[i] + frac * (pframe2[i] - pframe1[i]);
-          freq = pframe1[j] + frac * (pframe2[j] - pframe1[j]);
+          j       = i+1;
+          amp     = pframe1[i] + frac * (pframe2[i] - pframe1[i]);
+          freq    = pframe1[j] + frac * (pframe2[j] - pframe1[j]);
           fout[i] = (float) amp;
           fout[j] = (float) freq;
         }
@@ -464,7 +453,6 @@ int pvsmaskaset(CSOUND *csound, PVSMASKA *p)
     p->fout->winsize = p->winsize;
     p->fout->wintype = p->wintype;
     p->fout->format  = p->format;
-#ifndef OLPC
     p->fout->sliding = p->fsrc->sliding;
     if (p->fsrc->sliding) {
       csound->AuxAlloc(csound, (N + 2) * sizeof(MYFLT) * csound->ksmps,
@@ -472,7 +460,6 @@ int pvsmaskaset(CSOUND *csound, PVSMASKA *p)
       p->fout->NB = p->fsrc->NB;
     }
     else
-#endif
       {
         /* RWD MUST be 32bit */
         csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
@@ -502,7 +489,7 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
     int32 flen, nbins;
     MYFLT *ftable;
     float *fout,*fsrc;                      /* RWD MUST be 32bit */
-    float margin,depth = (float)*p->kdepth;
+    float margin, depth = (float)*p->kdepth;
 
     flen = p->maskfunc->flen + 1;
     ftable = p->maskfunc->ftable;
@@ -519,29 +506,28 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
                      "clipped to zero.\n"));
         p->nwarned = 1;
       }
-      depth = FL(0.0);
+      depth = 0.0f;
     }
-    if (depth > 1.0f) {
+    if (UNLIKELY(depth > 1.0f)) {
       if (UNLIKELY(!p->pwarned))  {
         csound->Warning(csound, Str("pvsmaska: kdepth > 1: clipped.\n"));
         p->pwarned = 1;
       }
-      depth = FL(1.0);
+      depth = 1.0f;
     }
     /* massage into internal mapping */
     /* user 0 --> my 1
        user 1 ---> my 0
        user 0.75 -->my 0.25
     */
-    depth = (float)(FL(1.0) - depth);
+    depth = (1.0f - depth);
 
-    margin = (float)(FL(1.0) - depth);
-#ifndef OLPC
+    margin = 1.0f - depth;
     if (p->fsrc->sliding) {
       int NB = p->fsrc->NB;
       CMPLX *fout, *fsrc;
       int n, nsmps=csound->ksmps;
-      MYFLT amp = 1.0f;
+      MYFLT amp = FL(1.0);
       for (n=0; n<nsmps; n++) {
         fout = (CMPLX *) p->fout->frame.auxp +n*NB;
         fsrc = (CMPLX *) p->fsrc->frame.auxp +n*NB;
@@ -553,11 +539,10 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
       }
       return OK;
     }
-#endif
     nbins = p->fftsize/2 + 1;
     /* only process when a new frame is ready */
     if (p->lastframe < p->fsrc->framecount) {
-      MYFLT amp = 1.0f;
+      MYFLT amp = FL(1.0);
       int aindex, findex;
       for (i=0;i < nbins;i++) {
         amp = depth + margin * ftable[i];
@@ -587,7 +572,7 @@ int pvsftwset(CSOUND *csound, PVSFTW *p)
     p->wintype = p->fsrc->wintype;
     p->format  = p->fsrc->format;
     p->fftsize = N;
-    p->outfna = p->outfnf = NULL;
+    p->outfna  = p->outfnf = NULL;
     p->lastframe = 0;
 
     if (UNLIKELY(!(p->format==PVS_AMP_FREQ) || (p->format==PVS_AMP_PHASE)))
@@ -600,10 +585,8 @@ int pvsftwset(CSOUND *csound, PVSFTW *p)
     p->outfna = csound->FTFind(csound, p->ifna);
     if (UNLIKELY(p->outfna==NULL))
       return NOTOK;
-#ifndef OLPC
     if (UNLIKELY(p->fsrc->sliding))
       csound->InitError(csound, Str("Sliding version not yet available"));
-#endif
     fsrc = (float *) p->fsrc->frame.auxp;               /* RWD MUST be 32bit */
     /* init table, one presumes with zero amps */
     nbins = p->fftsize/2 + 1;
@@ -618,7 +601,7 @@ int pvsftwset(CSOUND *csound, PVSFTW *p)
       ftablea[i] = fsrc[i*2];
 
     /* freq table? */
-    if ((int32) *p->ifnf >= 1.0f) {
+    if ((int32) *p->ifnf >= 1) {
       p->outfnf = csound->FTFind(csound, p->ifnf);
       if (UNLIKELY(p->outfnf==NULL))
         return NOTOK;
@@ -683,23 +666,23 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
     float *fdest;                         /* RWD MUST be 32bit */
     int32 flena,flenf,nbins, N = p->fdest->N;
     /* source fsig */
-    p->overlap = p->fdest->overlap;
-    p->winsize = p->fdest->winsize;
-    p->wintype = p->fdest->wintype;
-    p->format  = p->fdest->format;
-    p->fftsize = N;
-    p->infna = p->infnf = NULL;
-    p->ftablea = p->ftablef = NULL;
+    p->overlap   = p->fdest->overlap;
+    p->winsize   = p->fdest->winsize;
+    p->wintype   = p->fdest->wintype;
+    p->format    = p->fdest->format;
+    p->fftsize   = N;
+    p->infna     = p->infnf = NULL;
+    p->ftablea   = p->ftablef = NULL;
     p->lastframe = 0;
-    nbins = p->fftsize/2 + 1;
+    nbins        = p->fftsize/2 + 1;
 
     if (UNLIKELY(!(p->format==PVS_AMP_FREQ) || (p->format==PVS_AMP_PHASE)))
       csound->Die(csound, Str("pvsftr: signal format must be "
                               "amp-phase or amp-freq.\n"));
     /* ifn = 0 = notused */
-    if (UNLIKELY(*p->ifna < 0.0f))
+    if (UNLIKELY(*p->ifna < FL(0.0)))
       csound->Die(csound, Str("pvsftr: bad value for ifna.\n"));
-    if (UNLIKELY(*p->ifnf < 0.0f))
+    if (UNLIKELY(*p->ifnf < FL(0.0)))
       csound->Die(csound, Str("pvsftr: bad value for ifnf.\n"));
 
     /* if ifna=0; no amps to read; one assumes the user ias changing freqs only,
@@ -714,10 +697,8 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
       if (UNLIKELY(flena < nbins))
         csound->Die(csound, Str("pvsftr: amps ftable too small.\n"));
     }
-#ifndef OLPC
     if (UNLIKELY(p->overlap < csound->ksmps || p->overlap < 10))
       csound->InitError(csound, Str("Sliding version not yet available"));
-#endif
     fdest = (float *) p->fdest->frame.auxp;             /* RWD MUST be 32bit */
 
     /*** setup first frame ?? */
