@@ -58,7 +58,9 @@
 #include "csoundCore.h"
 #include "pvfileio.h"
 
+#if !defined(WAVE_FORMAT_EXTENSIBLE)
 #define WAVE_FORMAT_EXTENSIBLE  (0xFFFE)
+#endif
 #ifndef WAVE_FORMAT_PCM
 #define WAVE_FORMAT_PCM         (0x0001)
 #endif
@@ -150,7 +152,7 @@ static inline int byte_order(void)
 
 static inline int pvfile_read_tag(PVOCFILE *p, char *s)
 {
-    if ((int) fread(s, 1, 4, p->fp) != 4) {
+    if (UNLIKELY((int) fread(s, 1, 4, p->fp) != 4)) {
       s[0] = '\0';
       return -1;
     }
@@ -160,7 +162,7 @@ static inline int pvfile_read_tag(PVOCFILE *p, char *s)
 
 static inline int pvfile_write_tag(PVOCFILE *p, const char *s)
 {
-    if ((int) fwrite((void*) s, 1, 4, p->fp) != 4)
+    if (UNLIKELY((int) fwrite((void*) s, 1, 4, p->fp) != 4))
       return -1;
     return 0;
 }
@@ -296,7 +298,7 @@ const char *pvoc_errorstr(CSOUND *csound)
 {
     int i = -(csound->pvErrorCode);
 
-    if (i < 0 || i > 42) i = 1;
+    if (UNLIKELY(i < 0 || i > 42)) i = 1;
     return (const char *) Str(pvErrorStrings[i]);
 }
 
@@ -311,7 +313,7 @@ const char *pvoc_errorstr(CSOUND *csound)
 
 int init_pvsys(CSOUND *csound)
 {
-    if (csound->pvNumFiles) {
+    if (UNLIKELY(csound->pvNumFiles)) {
       csound->pvErrorCode = -2;
       return 0;
     }
@@ -321,7 +323,7 @@ int init_pvsys(CSOUND *csound)
 
 static inline PVOCFILE *pvsys_getFileHandle(CSOUND *csound, int fd)
 {
-    if (fd < 0 || fd >= csound->pvNumFiles)
+    if (UNLIKELY(fd < 0 || fd >= csound->pvNumFiles))
       return (PVOCFILE*) NULL;
     return (PVFILETABLE[fd]);
 }
@@ -434,10 +436,10 @@ int  pvoc_createfile(CSOUND *csound, const char *filename,
 
     }
 
-    if (wtype == PVOC_DEFAULT)
+    else if (wtype == PVOC_DEFAULT)
       wtype = PVOC_HAMMING;
 
-    if (wtype == PVOC_KAISER)
+    else if (wtype == PVOC_KAISER)
       if (wparam != 0.0f)
         winparam = wparam;
     /* will need an internal default for window parameters... */
@@ -964,7 +966,7 @@ int pvoc_fseek(CSOUND *csound, int ifd, int offset)
       csound->pvErrorCode = -37;
       return -1;
     }
-    if(offset == 1)
+    if (offset == 1)
     skipframes = (int32) p->fmtdata.nChannels;
     else skipframes = offset;
     skipsize = p->pvdata.dwFrameAlign * skipframes;
