@@ -140,7 +140,7 @@ int pvssanalset(CSOUND *csound, PVSANAL *p)
       double *s = c+NB;
       p->cosine = c;
       p->sine = s;
-      c[0] = 1.0; s[0] = 0.0;
+      c[0] = 1.0; s[0] = 0.0; // assignment to s unnecessary as auxalloc zeros
         /*
           direct computation of c and s may be better for large n
           c[i] = cos(2*M_PI*i/n);
@@ -228,13 +228,13 @@ int pvsanalset(CSOUND *csound, PVSANAL *p)
     }
     /* get net amp */
     sum = FL(0.0);
-    
+
     for (i = -halfwinsize; i <= halfwinsize; i++)
       sum += *(analwinhalf + i);
     sum = FL(2.0) / sum;  /* factor of 2 comes in later in trig identity */
     for (i = -halfwinsize; i <= halfwinsize; i++)
       *(analwinhalf + i) *= sum;
-    
+
 
   /*    p->invR = (float)(FL(1.0) / csound->esr); */
     p->RoverTwoPi = (float)(p->arate / TWOPI_F);
@@ -268,7 +268,7 @@ static void generate_frame(CSOUND *csound, PVSANAL *p)
     int32 analWinLen = p->fsig->winsize/2;
     int32 synWinLen = analWinLen;
     float *ofp;                 /* RWD MUST be 32bit */
-    MYFLT *fp,*oi,*i0,*i1;
+    MYFLT *fp;
     MYFLT *anal = (MYFLT *) (p->analbuf.auxp);
     MYFLT *input = (MYFLT *) (p->input.auxp);
     MYFLT *analWindow = (MYFLT *) (p->analwinbuf.auxp) + analWinLen;
@@ -384,7 +384,7 @@ static void generate_frame(CSOUND *csound, PVSANAL *p)
 
       /* add in filter center freq.*/
       /* *i1 */ anal[ii+1]  = angleDif * p->RoverTwoPi + ((MYFLT) i * p->Fexact);
-     
+
     }
     /* } */
     /* else must be PVOC_COMPLEX */
@@ -677,7 +677,7 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
 {
     MYFLT *analwinhalf;
     MYFLT *synwinhalf;
-    MYFLT sum, olapratio;
+    MYFLT sum;
     int32 halfwinsize,buflen;
     int i,nBins,Mf,Lf;
     double IO;
@@ -722,12 +722,12 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
     csound->AuxAlloc(csound, nBins * sizeof(MYFLT), &p->oldOutPhase);
     csound->AuxAlloc(csound, buflen * sizeof(MYFLT), &p->output);
 
-  
+
 
 
     synwinhalf = (MYFLT *) (p->synwinbuf.auxp) + halfwinsize;
- 
-    
+
+
 
     /* synthesis windows */
     if (M <= N) {
@@ -737,18 +737,19 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
       for (i = 1; i <= halfwinsize; i++)
         *(synwinhalf - i) = *(synwinhalf + i - Lf);
 
-       sum = FL(0.0); 
+
+       sum = FL(0.0);
         for (i = -halfwinsize; i <= halfwinsize; i++)
            sum += *(synwinhalf + i);
          sum = FL(2.0) / sum;
 
        for (i = -halfwinsize; i <= halfwinsize; i++)
         *(synwinhalf + i) *= sum;
-      
-         sum = FL(0.0); 
+
+         sum = FL(0.0);
    /* no timescaling, so I(nterpolation) will always = D(ecimation) = overlap */
         for (i = -halfwinsize; i <= halfwinsize; i+=overlap)
-	  sum += *(synwinhalf + i) * *(synwinhalf + i); 
+          sum += *(synwinhalf + i) * *(synwinhalf + i);
     }
     else {
      /* have to make analysis window to get amp scaling */
@@ -760,8 +761,8 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
 
     for (i = 1; i <= halfwinsize; i++)
       analwinhalf[-i] = analwinhalf[i - Mf];
-    
-      // sinc function 
+
+      // sinc function
       if (Mf)
         *analwinhalf *= (MYFLT)(dN * sin(PI*0.5/dN) / ( PI*0.5));
       for (i = 1; i <= halfwinsize; i++)
@@ -769,9 +770,9 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
           (dN * sin((double)(PI*(i+0.5*Mf)/dN)) / (PI*(i+0.5*Mf)));
       for (i = 1; i <= halfwinsize; i++)
         *(analwinhalf - i) = *(analwinhalf + i - Mf);
-    
+
      /* get net amp */
-    sum = FL(0.0); 
+    sum = FL(0.0);
     for (i = -halfwinsize; i <= halfwinsize; i++)
     sum += *(analwinhalf + i);
     sum = FL(2.0) / sum;  /* factor of 2 comes in later in trig identity */
@@ -791,12 +792,13 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
       for (i = 1; i <= halfwinsize; i++)
         *(synwinhalf - i) = *(synwinhalf + i - Lf);
     }
-   
+
+
    if (!(N & (N - 1L)))
      sum = csound->GetInverseRealFFTScale(csound, (int) N) / sum;
     else
       sum = FL(1.0) / sum;
-   
+
   for (i = -halfwinsize; i <= halfwinsize; i++)
       *(synwinhalf + i) *= sum;
 
@@ -810,6 +812,7 @@ int pvsynthset(CSOUND *csound, PVSYNTH *p)
     p->outptr = 0;
     p->nextOut = (MYFLT *) (p->output.auxp);
     p->buflen = buflen;
+
     return OK;
 }
 
@@ -826,9 +829,9 @@ static MYFLT synth_tick(CSOUND *csound, PVSYNTH *p)
 
 static void process_frame(CSOUND *csound, PVSYNTH *p)
 {
-    int n,i,j,k,ii,NO,NO2;
+    int i,j,k,ii,NO,NO2;
     float *anal;                                        /* RWD MUST be 32bit */
-    MYFLT *syn,*bsyn,*i0,*i1,*output;
+    MYFLT *syn,*bsyn,*output;
     MYFLT *oldOutPhase = (MYFLT *) (p->oldOutPhase.auxp);
     int32 N = p->fsig->N;
     MYFLT *obufptr,*outbuf,*synWindow;
@@ -940,7 +943,6 @@ static void process_frame(CSOUND *csound, PVSYNTH *p)
     obufptr = outbuf;
 
     for (i = 0; i < p->IOi;) {  /* shift out next IOi values */
-      int j;
       int todo = (p->IOi-i <= output+p->buflen - p->nextOut ?
                   p->IOi-i : output+p->buflen - p->nextOut);
       /*outfloats(nextOut, todo, ofd);*/
@@ -1099,4 +1101,3 @@ static void vonhann(MYFLT *win, int winLen, int even)
         win[i] = (MYFLT)(0.5 + 0.5 * cos(ftmp*(double)i));
     }
 }
-
