@@ -116,7 +116,7 @@ int lsgset(CSOUND *csound, LINSEG *p)
     MYFLT       **argp;
     double val;
 
-    nsegs = p->INOCOUNT >> 1;           /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (SEG *) p->auxch.auxp) == NULL ||
         nsegs*sizeof(SEG) < (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(SEG), &p->auxch);
@@ -341,7 +341,8 @@ int lsgrset(CSOUND *csound, LINSEG *p)
     int32 relestim;
     lsgset(csound,p);
     relestim = (p->cursegp + p->segsrem - 1)->cnt;
-    p->xtra = relestim;  /* VL 4-1-2011 was -1, making all linsegr releases in an instr => xtratim 
+    p->xtra = relestim;  /* VL 4-1-2011 was -1, making all linsegr
+                            releases in an instr => xtratim
                             set to relestim seems to fix this */
     if (relestim > p->h.insdshead->xtratim)
       p->h.insdshead->xtratim = (int)relestim;
@@ -387,7 +388,7 @@ int linsegr(CSOUND *csound, LINSEG *p)
     if (LIKELY(p->segsrem)) {               /* if no more segs putk */
       SEG *segp;
       if (p->h.insdshead->relesing && p->segsrem > 1) {
-        while (p->segsrem > 1) {            /* reles flag new:      */
+        while (p->segsrem > 1) {            /* release flag new:    */
           segp = ++p->cursegp;              /*   go to last segment */
           p->segsrem--;
         }                                   /*   get univ relestim  */
@@ -429,7 +430,7 @@ int xsgset(CSOUND *csound, EXXPSEG *p)
     MYFLT       d, **argp, val, dur, nxtval;
     int         n=0;
 
-    nsegs = p->INOCOUNT >> 1;                   /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (XSEG *) p->auxch.auxp) == NULL ||
         nsegs*sizeof(XSEG) < (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(XSEG), &p->auxch);
@@ -473,7 +474,7 @@ int xsgset_bkpt(CSOUND *csound, EXXPSEG *p)
     MYFLT       d, **argp, val, dur, dursum = FL(0.0), bkpt, nxtval;
     int         n=0;
 
-    nsegs = p->INOCOUNT >> 1;                   /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (XSEG *) p->auxch.auxp) == NULL ||
         nsegs*sizeof(XSEG) < (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(XSEG), &p->auxch);
@@ -523,7 +524,7 @@ int xsgset2b(CSOUND *csound, EXPSEG2 *p)
     MYFLT       d, **argp, val, dur, dursum = FL(0.0), bkpt, nxtval;
     int         n;
 
-    nsegs = p->INOCOUNT >> 1;           /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (XSEG*) p->auxch.auxp) == NULL ||
         (unsigned int)nsegs*sizeof(XSEG) > (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(XSEG), &p->auxch);
@@ -574,7 +575,7 @@ int xsgset2(CSOUND *csound, EXPSEG2 *p)   /*gab-A1 (G.Maldonado) */
     MYFLT       d, **argp, val, dur, nxtval;
     int         n;
 
-    nsegs = p->INOCOUNT >> 1;           /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (XSEG*) p->auxch.auxp) == NULL ||
         (unsigned int)nsegs*sizeof(XSEG) > (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(XSEG), &p->auxch);
@@ -740,7 +741,7 @@ int xsgrset(CSOUND *csound, EXPSEG *p)
     MYFLT   **argp, prvpt;
 
     p->xtra = -1;
-    nsegs = p->INOCOUNT >> 1;               /* count segs & alloc if nec */
+    nsegs = (p->INOCOUNT - (!(p->INOCOUNT & 1))) >> 1; /* count segs & alloc if nec */
     if ((segp = (SEG *) p->auxch.auxp) == NULL ||
         (unsigned int)nsegs*sizeof(SEG) > (unsigned int)p->auxch.size) {
       csound->AuxAlloc(csound, (int32)nsegs*sizeof(SEG), &p->auxch);
@@ -1295,7 +1296,7 @@ int evrset(CSOUND *csound, ENVLPR *p)
     else {
       p->phs = -1;
       p->val = *(ftp->ftable + ftp->flen)-asym;
-      /* irise = FL(0.0);          /* in case irise < 0 */
+      /* irise = FL(0.0); */          /* in case irise < 0 */
     }
     if (UNLIKELY(!(*(ftp->ftable + ftp->flen)))) {
       return csound->InitError(csound, Str("rise func ends with zero"));
@@ -1419,4 +1420,3 @@ int envlpxr(CSOUND *csound, ENVLPR *p)
     }
     return OK;
 }
-
