@@ -732,7 +732,9 @@ int multitap_set(CSOUND *csound, MDEL *p)
     int32 n;
     MYFLT max = FL(0.0);
 
-    if (UNLIKELY(p->INOCOUNT/2 == (MYFLT)p->INOCOUNT*FL(0.5)))
+    //if (UNLIKELY(p->INOCOUNT/2 == (MYFLT)p->INOCOUNT*FL(0.5)))
+    /* Should this test just be p->INOCOUNT&1 ==  */
+    if (UNLIKELY((p->INOCOUNT&1)==0))
       csound->Die(csound, Str("Wrong input count in multitap\n"));
 
     for (n = 0; n < p->INOCOUNT - 1; n += 2) {
@@ -992,9 +994,10 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
         p->z[i] = FL(0.0);
       }
       csound->AuxAlloc(csound, n * sizeof(MYFLT), &p->caux);
-      for (i = 0; i < n; i++) {
-        ((MYFLT*) p->caux.auxp)[i] = FL(0.0);
-      }
+      /* unnecessary as Auxlloc clears to 0 */
+      /* for (i = 0; i < n; i++) { */
+      /*   ((MYFLT*) p->caux.auxp)[i] = FL(0.0); */
+      /* } */
       p->pcbuf_cur[0] = p->cbuf_cur[0] = (MYFLT*)p->caux.auxp;
       for (i = 0; i < p->numCombs; i++) {
         p->pcbuf_cur[i + 1] = p->cbuf_cur[i + 1] =
@@ -1021,9 +1024,10 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
         n += a_time;
       }
       csound->AuxAlloc(csound, n * sizeof(MYFLT), &p->aaux);
-      for (i = 0; i < n; i++) {
-        ((MYFLT*) p->aaux.auxp)[i] = FL(0.0);
-      }
+      /* unnecessary as AuxAlloc clears */
+      /* for (i = 0; i < n; i++) { */
+      /*   ((MYFLT*) p->aaux.auxp)[i] = FL(0.0); */
+      /* } */
       p->pabuf_cur[0] = p->abuf_cur[0] = (MYFLT*) p->aaux.auxp;
       for (i = 0; i < p->numAlpas; i++) {
         p->pabuf_cur[i + 1] = p->abuf_cur[i + 1] =
