@@ -29,7 +29,7 @@ typedef struct {
     OPDS    h;                                      /* required header */
     MYFLT   *mw, *mx, *my, *mz, *mr, *ms, *mt, *mu, *mv, *mk,
             *ml, *mm, *mn, *mo, *mp, *mq;           /* addr outarg */
-  MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
+    MYFLT   *asig, *kalpha, *kbeta, *kin[4];          /* addr inargs */
     /* private dataspace */
     double  w, x, y, z, r, s, t, u, v, k, l, m, n, o, p, q;
 } AMBIC;
@@ -714,9 +714,9 @@ static int aambideco(CSOUND *csound, AMBID *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-  { "bformenc", S(AMBIC), 5, "mmmmmmmmmmmmmmmm", "akkPPPP",
+  { "bformenc", S(AMBIC), _QQ|5, "mmmmmmmmmmmmmmmm", "akkPPPP",
                             (SUBR)iambicode, NULL, (SUBR)aambicode },
-  { "bformdec", S(AMBID), 5, "mmmmmmmm", "iaaay",
+  { "bformdec", S(AMBID), _QQ|5, "mmmmmmmm", "iaaay",
                             (SUBR)iambideco, NULL, (SUBR)aambideco }
 };
 
