@@ -445,9 +445,8 @@ static int vco(CSOUND *csound, VCO *p)
     rtfqc = SQRT(fqc);
     knh = (int)(csound->esr*p->nyq/fqc);
     if (UNLIKELY((n = (int)knh) <= 0)) {
-      csound->Message(csound, "knh=%x nyq=%f fqc=%f\n", knh, p->nyq, fqc);
-                                /* Line apparently missing here */
-      csound->Message(csound, Str("vco knh (%d) <= 0; taken as 1\n"), n);
+      csound->Warning(csound, "knh=%x nyq=%f fqc=%f\n"
+                      "vco knh (%d) <= 0; taken as 1\n", knh, p->nyq, fqc, n);
       n = 1;
     }
     tnp1 = n + n + 1;           /* calc 2n + 1 */
@@ -1297,8 +1296,8 @@ static OENTRY localops[] = {
 { "moogvcf2", S(MOOGVCF),5, "a", "axxoo", (SUBR)moogvcfset, NULL, (SUBR)moogvcf },
 { "rezzy", S(REZZY),     5, "a", "axxoo", (SUBR)rezzyset, NULL, (SUBR)rezzy },
 { "bqrez", S(REZZY),     5, "a", "axxoo", (SUBR)bqrezset, NULL, (SUBR)bqrez },
-{ "distort1", S(DISTORT),4, "a", "akkkko",  NULL,   NULL,   (SUBR)distort   },
-{ "vco", S(VCO),         5, "a", "xxiVppovoo",(SUBR)vcoset, NULL, (SUBR)vco },
+{ "distort1", S(DISTORT),TR|4, "a", "akkkko",  NULL,   NULL,   (SUBR)distort   },
+{ "vco", S(VCO),      TR|5, "a", "xxiVppovoo",(SUBR)vcoset, NULL, (SUBR)vco },
 { "tbvcf", S(TBVCF),     5, "a", "axxkkp",  (SUBR)tbvcfset, NULL, (SUBR)tbvcf   },
 { "planet", S(PLANET),5,"aaa","kkkiiiiiiioo", (SUBR)planetset, NULL, (SUBR)planet},
 { "pareq", S(PAREQ),     5, "a", "akkkoo",(SUBR)pareqset, NULL, (SUBR)pareq },
