@@ -54,6 +54,7 @@ static CS_NOINLINE int fout_deinit_callback(CSOUND *csound, void *p_)
           pp->name = (char*) NULL;
           pp->do_scale = 0;
           pp->refCount = 0U;
+      
           if (pp->fd != NULL) {
             if ((csound->oparms->msglevel & 7) == 7)
               csound->Message(csound, Str("Closing file '%s'...\n"),
@@ -166,7 +167,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
         csound->Free(csound, name);
         return -1;
       }
-      /*      setvbuf(f, (char *) NULL, _IOLBF, 0); /* Ensure line buffering */
+      /* setvbuf(f, (char *) NULL, _IOLBF, 0); */ /* Ensure line buffering */
       pp->file_opened[idx].raw = f;
       pp->file_opened[idx].fd = fd;
     }
@@ -451,7 +452,7 @@ static int ficlose_opcode(CSOUND *csound, FICLOSE *p)
     }
     else {
       FOUT_FILE tmp;
-      pp->file_opened[idx].refCount = 0x80000001U;
+      pp->file_opened[idx].refCount = 1; /*ref count was set to 0x80000001U, but it needs to be 1 */
       memset(&tmp, 0, sizeof(FOUT_FILE));
       tmp.h.insdshead = p->h.insdshead;
       tmp.idx = idx + 1;
@@ -515,7 +516,7 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
     }
     else { /* binary format */
       for (j = 0; j < p->INOCOUNT - 3; j++) {
-        fwrite(args[j], sizeof(MYFLT), 1, rfil);
+        if (UNLIKELY(1!=fwrite(args[j], sizeof(MYFLT), 1, rfil))) return NOTOK;
       }
     }
     return OK;
@@ -582,7 +583,7 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
     }
     else { /* binary format */
       for (j = 0; j < p->INOCOUNT - 3; j++) {
-        fwrite(args[j], sizeof(MYFLT), 1, rfil);
+        if (UNLIKELY(1!=fwrite(args[j], sizeof(MYFLT), 1, rfil))) return NOTOK;
       }
     }
     p->done = 0;
@@ -686,7 +687,7 @@ static int kinfile(CSOUND *csound, KINFILE *p)
 
     if (p->flag) {
       sf_seek(p->f.sf, p->currpos, SEEK_SET);
-      p->currpos++;
+       p->currpos++;
 #ifndef USE_DOUBLE
       n = (int) sf_readf_float(p->f.sf, (float*) pp->buf, 1);
 #else
