@@ -19,7 +19,8 @@
 /* This file includes the opcodes from newopcodes.c */
 /* TODO: Check if the authors (Peter Neubaeker and Jens Groh) are correct */
 
-/*printi removed? I can't find the corresponding OENTRY- Left them commented out */
+/*printi removed? I can't find the corresponding OENTRY- */
+/*Left them commented out */
 /*how should exitnow be safely implemented? */
 /*Check the zak opcodes */
 /*changed some comments to c-style */
@@ -29,6 +30,7 @@
 #include "csdl.h"
 #include "gab.h"
 #include <math.h>
+#include "interlocks.h"
 
 static int krsnsetx(CSOUND *csound, KRESONX *p)
   /* Gabriel Maldonado, modifies for arb order  */
@@ -112,7 +114,7 @@ static int fastab_set(CSOUND *csound, FASTAB *p)
     p->tablen = ftp->flen;
     p->xmode = (int) *p->ixmode;
     if (p->xmode)
-      p->xbmul = (MYFLT) ftp->flen;
+      p->xbmul = (MYFLT) p->tablen /*- FL(0.001)*/;
     else
       p->xbmul = FL(1.0);
     return OK;
@@ -127,7 +129,7 @@ static int fastabw(CSOUND *csound, FASTAB *p)
       MYFLT xbmul = p->xbmul;   /* load once */
       for (n=0; n<nsmps; n++)  { /* for loops compile better */
         int i = (int)(ndx[n]*xbmul);
-        if (UNLIKELY(i >= p->tablen || i<0)) {
+        if (UNLIKELY(i > p->tablen || i<0)) {
           csound->Message(csound, "ndx: %f \n", ndx[n]);
           return csound->PerfError(csound, Str("tabw off end"));
         }
@@ -137,7 +139,7 @@ static int fastabw(CSOUND *csound, FASTAB *p)
     else {
       for (n=0; n<nsmps; n++) {
         int i = ndx[n];
-        if (UNLIKELY(i >= p->tablen || i<0)) {
+        if (UNLIKELY(i > p->tablen || i<0)) {
           return csound->PerfError(csound, Str("tabw off end"));
         }
         tab[i] = rslt[n];
@@ -153,7 +155,7 @@ static int fastabk(CSOUND *csound, FASTAB *p)
       i = (int) (*p->xndx * p->xbmul);
     else
       i = (int) *p->xndx;
-    if (UNLIKELY(i >= p->tablen || i<0)) {
+    if (UNLIKELY(i > p->tablen || i<0)) {
       return csound->PerfError(csound, Str("tab off end"));
     }
     *p->rslt =  p->table[i];
@@ -167,7 +169,7 @@ static int fastabkw(CSOUND *csound, FASTAB *p)
       i = (int) (*p->xndx * p->xbmul);
     else
       i = (int) *p->xndx;
-    if (UNLIKELY(i >= p->tablen || i<0)) {
+    if (UNLIKELY(i > p->tablen || i<0)) {
       return csound->PerfError(csound, Str("tabw off end"));
     }
     p->table[i] = *p->rslt;
@@ -187,7 +189,7 @@ static int fastabi(CSOUND *csound, FASTAB *p)
     else
       i = (int) *p->xndx;
     if (UNLIKELY(i >= ftp->flen || i<0)) {
-        return csound->PerfError(csound, Str("tab_i off end"));
+      return csound->PerfError(csound, Str("tab_i off end: table number: %d\n"), (int) *p->xfn);
     }
     *p->rslt =  ftp->ftable[i];
     return OK;
@@ -221,7 +223,7 @@ static int fastab(CSOUND *csound, FASTAB *p)
       MYFLT xbmul = p->xbmul;
       for (i=0; i<nsmps; i++) {
         int n = (int) (ndx[i] * xbmul);
-        if (UNLIKELY(n >= p->tablen || n<0)) {
+        if (UNLIKELY(n > p->tablen || n<0)) {
           return csound->PerfError(csound, Str("tab off end"));
         }
         rslt[i] = tab[n];
@@ -230,7 +232,7 @@ static int fastab(CSOUND *csound, FASTAB *p)
     else {
       for (i=0; i<nsmps; i++) {
         int n = (int) ndx[i];
-        if (UNLIKELY(n >= p->tablen || n<0)) {
+        if (UNLIKELY(n > p->tablen || n<0)) {
           return csound->PerfError(csound, Str("tab off end"));
         }
         rslt[i] = tab[n];
@@ -709,28 +711,28 @@ static int partial_maximum(CSOUND *csound,P_MAXIMUM *p)
     MYFLT *a = p->asig;
     MYFLT max = p->max;
     switch(flag) {
-    case 0: /* absolute maximum */
+    case 1: /* absolute maximum */
       for (n=0; n<nsmps; n++) {
         MYFLT temp;
         if ((temp = FABS(a[n])) > max) max = temp;
       }
       if (max > p->max) p->max = max;
       break;
-    case 1: /* actual maximum */
+    case 2: /* actual maximum */
       for (n=0; n<nsmps; n++) {
         if (a[n] > max) max = a[n];
       }
       if (max > p->max) p->max = max;
       break;
-    case 2: /* actual minimum */
+    case 3: /* actual minimum */
       for (n=0; n<nsmps; n++) {
         if (a[n] < max) max = a[n];
       }
       if (max < p->max) p->max = max;
       break;
-    case 3: { /* average */
+    case 4: { /* average */
         MYFLT temp = FL(0.0);
-        p->counter += n;
+        p->counter += nsmps;
         for (n=0; n<nsmps; n++) {
           temp += a[n];
         }
@@ -741,11 +743,12 @@ static int partial_maximum(CSOUND *csound,P_MAXIMUM *p)
       return csound->PerfError(csound, Str("max_k: invalid imaxflag value"));
     }
     if (*p->ktrig) {
-      if (flag == 3) {
+      if (flag == 4) {
         *p->kout = p->max / (MYFLT) p->counter;
         p->counter = 0;
       }
-      else *p->kout = p->max;
+      else
+        *p->kout = p->max;
       p->max = FL(0.0);
     }
     return OK;
@@ -789,31 +792,31 @@ static int mandel(CSOUND *csound,MANDEL *p)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
+OENTRY gab_localops[] = {
   {"resonxk", S(KRESONX),    3,   "k",    "kkkooo",
                             (SUBR) krsnsetx, (SUBR) kresonx, NULL },
-  { "tab_i",S(FASTAB),       1,   "i",    "iio", (SUBR) fastabi, NULL, NULL },
-  { "tab",S(FASTAB),         7,   "s",    "xio",
+  { "tab_i",S(FASTAB),       TR|1,   "i",    "iio", (SUBR) fastabi, NULL, NULL },
+  { "tab",S(FASTAB),         TR|7,   "s",    "xio",
                             (SUBR) fastab_set, (SUBR)fastabk, (SUBR) fastab },
-  { "tabw_i",S(FASTAB),      1,   "",    "iiio", (SUBR) fastabiw, NULL, NULL },
-  { "tabw",S(FASTAB),        7,   "",    "xxio",
+  { "tabw_i",S(FASTAB),      TW|1,   "",    "iiio", (SUBR) fastabiw, NULL, NULL },
+  { "tabw",S(FASTAB),        TW|7,   "",    "xxio",
                             (SUBR)fastab_set, (SUBR)fastabkw, (SUBR)fastabw },
-  { "tb0_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab0_init},
-  { "tb1_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab1_init},
-  { "tb2_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab2_init},
-  { "tb3_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab3_init},
-  { "tb4_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab4_init},
-  { "tb5_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab5_init},
-  { "tb6_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab6_init},
-  { "tb7_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab7_init},
-  { "tb8_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab8_init},
-  { "tb9_init", S(TB_INIT),  1,   "",      "i",    (SUBR)tab9_init},
-  { "tb10_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab10_init},
-  { "tb11_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab11_init},
-  { "tb12_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab12_init},
-  { "tb13_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab13_init},
-  { "tb14_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab14_init},
-  { "tb15_init", S(TB_INIT), 1,   "",      "i",    (SUBR)tab15_init},
+  { "tb0_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab0_init},
+  { "tb1_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab1_init},
+  { "tb2_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab2_init},
+  { "tb3_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab3_init},
+  { "tb4_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab4_init},
+  { "tb5_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab5_init},
+  { "tb6_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab6_init},
+  { "tb7_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab7_init},
+  { "tb8_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab8_init},
+  { "tb9_init", S(TB_INIT),  TR|1,   "",      "i",    (SUBR)tab9_init},
+  { "tb10_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab10_init},
+  { "tb11_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab11_init},
+  { "tb12_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab12_init},
+  { "tb13_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab13_init},
+  { "tb14_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab14_init},
+  { "tb15_init", S(TB_INIT), TR|1,   "",      "i",    (SUBR)tab15_init},
   { "tb0.k",  S(FASTB), 2,  "k",    "k",    NULL, (SUBR) tab0_k_tmp,  NULL  },
   { "tb1.k",  S(FASTB), 2,  "k",    "k",    NULL, (SUBR) tab1_k_tmp,  NULL  },
   { "tb2.k",  S(FASTB), 2,  "k",    "k",    NULL, (SUBR) tab2_k_tmp,  NULL  },
@@ -849,7 +852,7 @@ static OENTRY localops[] = {
   { "tb15.i",     S(FASTB), 1,    "i",     "i",    (SUBR) tab15_i_tmp   },
   { "nlalp",      S(NLALP), 5,    "a",     "akkoo",
                             (SUBR) nlalp_set, NULL, (SUBR) nlalp   },
-  { "adsynt2",S(ADSYNT2),   5,    "a",     "kkiiiio",
+  { "adsynt2",S(ADSYNT2),TR|5,    "a",     "kkiiiio",
                             (SUBR) adsynt2_set, NULL, (SUBR)adsynt2 },
   { "exitnow",S(EXITNOW),   1,    "",  "", (SUBR) exitnow, NULL, NULL },
 /* { "zr_i",  S(ZKR),     1,  "i",  "i",  (SUBR)zread, NULL, NULL}, */
@@ -860,22 +863,22 @@ static OENTRY localops[] = {
 /* { "a_k",   S(INDIFF),  5,  "a",  "k",  (SUBR)a_k_set,NULL, (SUBR)interp }, */
   { "tabrec",   S(TABREC),  3,     "",      "kkkkz",
                             (SUBR) tabrec_set, (SUBR) tabrec_k, NULL },
-  { "tabplay",  S(TABPLAY), 3,     "",      "kkkz",
+  { "tabplay",  S(TABPLAY), TR|3,     "",      "kkkz",
                             (SUBR) tabplay_set, (SUBR) tabplay_k, NULL },
   { "changed", S(ISCHANGED), 3,     "k",     "z",
                             (SUBR) isChanged_set, (SUBR)isChanged, NULL },
   /*{ "ftlen_k",S(EVAL),    2,      "k",    "k", NULL,      (SUBR)ftlen   }, */
   { "max_k",  S(P_MAXIMUM), 5,      "k",    "aki",
             (SUBR) partial_maximum_set, (SUBR) NULL, (SUBR) partial_maximum },
-  { "maxk",   S(P_MAXIMUM), 5,      "k",    "aki",
-            (SUBR) partial_maximum_set, (SUBR) NULL, (SUBR) partial_maximum },
+/*{ "maxk",   S(P_MAXIMUM), 5,      "k",    "aki", */
+/*        (SUBR) partial_maximum_set, (SUBR) NULL, (SUBR) partial_maximum }, */
   { "mandel",S(MANDEL),     3,      "kk",    "kkkk",
                             (SUBR) mandel_set, (SUBR) mandel, NULL }
 };
 
 int gab_gab_init_(CSOUND *csound)
 {
-    return csound->AppendOpcodes(csound, &(localops[0]),
-                                 (int) (sizeof(localops) / sizeof(OENTRY)));
+    return csound->AppendOpcodes(csound, &(gab_localops[0]),
+                                 (int) (sizeof(gab_localops) / sizeof(OENTRY)));
 }
 
