@@ -16,7 +16,8 @@
   02111-1307 USA
 */
 
-#include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
 
 /* (Shouldn't there be global decl's for these?) */
 #define INCR (0.001f)
@@ -164,7 +165,8 @@ static int schedInTime_set(CSOUND *csound, SCHEDINTIME *p)
      int *xtra;
      int j;
      OPARMS    *O = csound->oparms;
-     static MYFLT frac = 0; /* hugly hack, needs to be inserted in the CSOUND structure */
+     /* hugly hack, needs to be inserted in the CSOUND structure */
+     static MYFLT frac = 0;
 
      O->RTevents = 1;     /* Make sure kperf() looks for RT events */
      /*   O.ksensing = 1; */
@@ -236,24 +238,24 @@ static int copyTabElems_set(CSOUND *csound, COPYTABELEMS *p)
     int nelems = (int) *p->inumElems;
     if ((ftp = csound->FTFind(csound, p->idestTab)) == NULL)
       return csound->InitError(csound,
-                               "copyTabElems: incorrect destination table number");
+                               Str("copyTabElems: incorrect destination table number"));
 
     p->dLen = ftp->flen;
     if (nelems > p->dLen)
       return csound->InitError(csound,
-                               "copyTabElems: destination table too short "
-                               "or number of elements to copy too big");
+                               Str("copyTabElems: destination table too short "
+                                   "or number of elements to copy too big"));
 
     p->dTable = ftp->ftable;
     if ((ftp = csound->FTFind(csound, p->isourceTab)) == NULL)
       return csound->InitError(csound,
-                               "copyTabElems: incorrect source table number");
+                               Str("copyTabElems: incorrect source table number"));
 
     p->sLen = ftp->flen;
     if (nelems > p->sLen)
       return csound->InitError(csound,
-                               "copyTabElems: source table size less than "
-                               "the number of elements to copy");
+                               Str("copyTabElems: source table size less than "
+                                   "the number of elements to copy"));
 
     p->sTable = ftp->ftable;
 
@@ -268,10 +270,10 @@ static int copyTabElems(CSOUND *csound, COPYTABELEMS *p)
       int j, sNdx = (int) *p->ksourceIndex * nelems,
              dNdx = (int) *p->kdestIndex * nelems;
       if (sNdx + nelems > p->sLen)
-        return csound->PerfError(csound, "copyTabElems: source table too short");
+        return csound->PerfError(csound, Str("copyTabElems: source table too short"));
       if (dNdx + nelems > p->dLen)
         return csound->PerfError(csound,
-                                 "copyTabElems: destination table too short");
+                                 Str("copyTabElems: destination table too short"));
 
       for (j = 0; j< nelems; j++)
         p->dTable[dNdx+j] = p->sTable[sNdx+j];
@@ -291,31 +293,32 @@ static int copyTabElemsi(CSOUND *csound, COPYTABELEMS_I *p)
     MYFLT *sTable, *dTable;
     if ((ftp = csound->FTFind(csound, p->idestTab)) == NULL)
       return csound->InitError(csound,
-                               "copyTabElems: incorrect destination table number");
+                               Str("copyTabElems: incorrect destination "
+                                   "table number"));
     dLen = ftp->flen;
     if (nelems > dLen)
       return csound->InitError(csound,
-                               "copyTabElems: destination table too short "
-                               "or number of elements to copy too big");
+                               Str("copyTabElems: destination table too short "
+                                   "or number of elements to copy too big"));
     dTable = ftp->ftable;
     if ((ftp = csound->FTFind(csound, p->isourceTab)) == NULL)
       return csound->InitError(csound,
-                               "copyTabElems: incorrect source table number");
+                               Str("copyTabElems: incorrect source table number"));
     sLen = ftp->flen;
     if (nelems > sLen)
       return csound->InitError(csound,
-                               "copyTabElems: source table size less than "
-                               "the number of elements to copy");
+                               Str("copyTabElems: source table size less than "
+                                   "the number of elements to copy"));
     sTable = ftp->ftable;
 
     {
       int j, sNdx = (int) *p->isourceIndex * nelems,
         dNdx = (int) *p->idestIndex * nelems;
       if (sNdx + nelems > sLen)
-        return csound->PerfError(csound, "copyTabElems: source table too short");
+        return csound->PerfError(csound, Str("copyTabElems: source table too short"));
       if (dNdx + nelems > dLen)
         return csound->PerfError(csound,
-                                 "copyTabElems: destination table too short");
+                                 Str("copyTabElems: destination table too short"));
       for (j = 0; j< nelems; j++) {
         dTable[dNdx+j] = sTable[sNdx+j];
       }
@@ -341,7 +344,7 @@ static int inRange_i(CSOUND *csound, INRANGE *p)
     p->narg = p->INOCOUNT-1;
 /*p->numChans = (PortaudioNumOfInPorts == -1) ? nchnls : PortaudioNumOfInPorts; */
     if (!csound->oparms->sfread)
-      return csound->InitError(csound, "inrg: audio input is not enabled");
+      return csound->InitError(csound, Str("inrg: audio input is not enabled"));
     p->numChans = csound->nchnls;
     return OK;
 }
@@ -405,9 +408,7 @@ static int outRange(CSOUND *csound, OUTRANGE *p)
 
     nsmps = ksmps;
     if (!csound->spoutactive) {
-      MYFLT *sptemp = sp;
       memset(sp, 0, ksmps * nchnls * sizeof(MYFLT));
-      /* for (j=0; j< ksmps * nchnls; j++) *sptemp++ = 0; /\* clear all channels *\/ */
       for (n=0; n<nsmps; n++) {
         int i;
         MYFLT *sptemp = sp;
@@ -570,10 +571,10 @@ static int lposcint_stereo_set(CSOUND *csound, LPOSCINT_ST *p)
     FUNC *ftp;
     double  loop, end, looplength, fsr;
     if ((ftp = csound->FTnp2Find(csound, p->ift)) == NULL)
-      return csound->InitError(csound, "invalid function");
+      return csound->InitError(csound, Str("invalid function"));
     if (!(fsr = ftp->gen01args.sample_rate)){
       csound->Message(csound,
-                      "lposcil: no sample rate stored in function assuming=sr\n");
+                      Str("lposcil: no sample rate stored in function assuming=sr\n"));
       p->fsr=csound->esr;
     }
     p->fsrUPsr = fsr/csound->esr;
@@ -803,7 +804,7 @@ static int dashow (CSOUND *csound, DSH *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-  { "vtable1k",       S(MTABLE1),         3,  "",  "kz",          (SUBR)mtable1_set,      (SUBR)mtable1_k,        (SUBR) NULL },
+  { "vtable1k",       S(MTABLE1),         TR|3,  "",  "kz",          (SUBR)mtable1_set,      (SUBR)mtable1_k,        (SUBR) NULL },
   /*      { "schedk",         S(SCHEDK),          3,  "",  "kkz",         (SUBR)schedk_i,         (SUBR) schedk,          (SUBR) NULL }, */
   /*      { "schedInTime",    S(SCHEDINTIME),     3,  "",  "kz",          (SUBR)schedInTime_set,  (SUBR)schedInTime ,     (SUBR) NULL }, */
   /*      { "copyTabElems",   S(COPYTABELEMS),    3,  "",  "kikiki",      (SUBR)copyTabElems_set, (SUBR)copyTabElems,     (SUBR)NULL  }, */
@@ -813,9 +814,9 @@ static OENTRY localops[] = {
   /*      { "lposcinta",      S(LPOSC),           5,      "a", "akkkio",      (SUBR)lposc_set,            NULL,                                   (SUBR)lposcinta}, */
   /*      { "lposcintsa",     S(LPOSCINT_ST),     5,  "aa","akkkio",              (SUBR)lposcint_stereo_set,NULL,                                 (SUBR)lposcinta_stereo}, */
   /*      { "lposcintsa2",    S(LPOSCINT_ST),     5,  "aa","akkkio",              (SUBR)lposcint_stereo_set,NULL,                                 (SUBR)lposcinta_stereo_no_trasp}, */
-  { "lposcila", S(LPOSC),      5, "a", "akkkio", (SUBR)lposc_set, NULL, (SUBR)lposca},
-  { "lposcilsa", S(LPOSC_ST),  5, "aa","akkkio", (SUBR)lposc_stereo_set, NULL, (SUBR)lposca_stereo},
-  { "lposcilsa2", S(LPOSC_ST), 5, "aa","akkkio", (SUBR)lposc_stereo_set, NULL, (SUBR)lposca_stereo_no_trasp},
+  { "lposcila", S(LPOSC),      TR|5, "a", "akkkio", (SUBR)lposc_set, NULL, (SUBR)lposca},
+  { "lposcilsa", S(LPOSC_ST),  TR|5, "aa","akkkio", (SUBR)lposc_stereo_set, NULL, (SUBR)lposca_stereo},
+  { "lposcilsa2", S(LPOSC_ST), TR|5, "aa","akkkio", (SUBR)lposc_stereo_set, NULL, (SUBR)lposca_stereo_no_trasp},
   /* { "dashow.i", S(DSH), 1,  "ii","iiii", (SUBR)dashow     }, */
   /* { "dashow.k", S(DSH), 2,  "kk","kkkk", NULL, (SUBR)dashow   }, */
   { "inrg", S(INRANGE), 5, "", "ky", (SUBR)inRange_i, (SUBR)NULL, (SUBR)inRange },
@@ -829,6 +830,7 @@ typedef struct NEWGABOPC_GLOBALS_ {
 
 } NEWGABOPC_GLOBALS;
 
+/*
 PUBLIC int csoundModuleInfo(void)
 {
     return ((CS_APIVERSION << 16) + (CS_APISUBVER << 8) + (int) sizeof(MYFLT));
@@ -840,8 +842,7 @@ PUBLIC int csoundModuleCreate(CSOUND *csound)
     (void)csound;
     return 0;
 }
-
-
+*/
 
 
 int newgabopc_init_(CSOUND *csound) {
@@ -855,7 +856,7 @@ int tabmorph_init_(CSOUND *csound);
 int rbatonopc_init_(CSOUND *csound);
 
 
-PUBLIC int csoundModuleInit(CSOUND *csound)
+int newgabopc_ModuleInit(CSOUND *csound)
 {
         int               err = 0;
         err |= hvs_init_(csound);
@@ -868,7 +869,9 @@ PUBLIC int csoundModuleInit(CSOUND *csound)
         return (err ? CSOUND_ERROR : CSOUND_SUCCESS);
 }
 
+/*
 PUBLIC  int     csoundModuleDestroy(CSOUND *csound)
 {
     return 0;
 }
+*/
