@@ -21,7 +21,9 @@
     02111-1307 USA
 */
 
-#include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
+
 #include <math.h>
 
 typedef struct {
@@ -131,7 +133,7 @@ static int harmon234(CSOUND *csound, HARM234 *p)
     MYFLT       koct, vocamp, diramp;
     PULDAT      *endp;
     VOCDAT      *vdp;
-    int16       n, nsmps, oflow = 0;
+    int16       nsmps, oflow = 0;
 
     if ((koct = *p->koct) != p->prvoct) {               /* if new pitch estimate */
       if (koct >= p->minoct) {                          /*   above requested low */
@@ -432,11 +434,11 @@ int harmon4(CSOUND *csound, HARMON4 *p) { return harmon234(csound, &p->hrmdat);}
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
+static OENTRY harmon_localops[] = {
   { "harmon2",S(HARMON2),5, "a",  "akkkiip",  (SUBR)harm2set,NULL, (SUBR)harmon2 },
   { "harmon3",S(HARMON3),5, "a",  "akkkkiip", (SUBR)harm3set,NULL, (SUBR)harmon3 },
-  { "harmon4",S(HARMON4),5, "a",  "akkkkkiip",(SUBR)harm4set,NULL, (SUBR)harmon4 }
+  { "harmon4",S(HARMON4),5, "a",  "akkkkkiip",(SUBR)harm4set,NULL, (SUBR)harmon4 },
 };
 
-LINKAGE
+LINKAGE1(harmon_localops)
 
