@@ -21,7 +21,9 @@
     02111-1307 USA
 */
 
-#include "csdl.h"
+// #include "csdl.h"
+#include "csoundCore.h"
+#include "interlocks.h"
 #include "soundio.h"
 
 typedef struct SNDLOAD_OPCODE_ {
@@ -667,12 +669,11 @@ static int loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
 
  /* ------------------------------------------------------------------------ */
 
-static OENTRY localops[] = {
+static OENTRY loscilx_localops[] = {
   { "sndload",  sizeof(SNDLOAD_OPCODE), 1,  "",                 "Tooooojjoo",
     (SUBR) sndload_opcode_init, (SUBR) NULL, (SUBR) NULL                      },
-  { "loscilx",  sizeof(LOSCILX_OPCODE), 5,  "mmmmmmmmmmmmmmmm", "xkToojjoo",
+  { "loscilx",  sizeof(LOSCILX_OPCODE), TR|5,  "mmmmmmmmmmmmmmmm", "xkToojjoo",
     (SUBR) loscilx_opcode_init, (SUBR) NULL, (SUBR) loscilx_opcode_perf       }
 };
 
-LINKAGE
-
+LINKAGE1(loscilx_localops)
