@@ -255,8 +255,8 @@ static int seqtim2(CSOUND *csound, SEQTIM2 *p)
 #define S(x)    sizeof(x)
 
 static OENTRY localops[] = {
-{ "seqtime", S(SEQTIM),  3, "k",    "kkkkk", (SUBR)seqtim_set, (SUBR)seqtim   },
-{ "seqtime2", S(SEQTIM2),3, "k",    "kkkkkk", (SUBR)seqtim2_set, (SUBR)seqtim2}
+{ "seqtime", S(SEQTIM),  TR|3, "k",    "kkkkk", (SUBR)seqtim_set, (SUBR)seqtim   },
+{ "seqtime2", S(SEQTIM2),TR|3, "k",    "kkkkkk", (SUBR)seqtim2_set, (SUBR)seqtim2}
 };
 
 int seqtime_init_(CSOUND *csound)
