@@ -28,7 +28,6 @@ functions specific to sixteen loudspeaker VBAP
 Ville Pulkki
 */
 
-#ifndef OLPC
 
 #include "csdl.h"
 #include "vbap.h"
@@ -200,9 +199,9 @@ int vbap_SIXTEEN_init(CSOUND *csound, VBAP_SIXTEEN *p)
     p->ls_am     = (int) ls_table[1];
     p->ls_set_am = (int) ls_table[2];
     ptr = &(ls_table[3]);
-    if(!p->ls_set_am)
-      return csound->InitError(csound, Str("vbap system NOT configured. \
-           \nMissing vbaplsinit opcode in orchestra?"));
+    if (!p->ls_set_am)
+      return csound->InitError(csound, Str("vbap system NOT configured. \nMissing"
+                                           " vbaplsinit opcode in orchestra?"));
     csound->AuxAlloc(csound, p->ls_set_am * sizeof (LS_SET), &p->aux);
     if (UNLIKELY(p->aux.auxp == NULL)) {
       return csound->InitError(csound, Str("could not allocate memory"));
@@ -483,9 +482,9 @@ int vbap_SIXTEEN_moving_init(CSOUND *csound, VBAP_SIXTEEN_MOVING *p)
     p->ls_am     = (int) ls_table[1];
     p->ls_set_am = (int) ls_table[2];
     ptr = &(ls_table[3]);
-    if(!p->ls_set_am)
-      return csound->InitError(csound, Str("vbap system NOT configured. \
-           \nMissing vbaplsinit opcode in orchestra?"));
+    if (!p->ls_set_am)
+      return csound->InitError(csound, Str("vbap system NOT configured.\nMissing"
+                                           " vbaplsinit opcode in orchestra?"));
     csound->AuxAlloc(csound, p->ls_set_am * sizeof (LS_SET), &p->aux);
     if (UNLIKELY(p->aux.auxp == NULL)) {
       return csound->InitError(csound, Str("could not allocate memory"));
@@ -544,5 +543,3 @@ int vbap_SIXTEEN_moving_init(CSOUND *csound, VBAP_SIXTEEN_MOVING *p)
     }
     return OK;
 }
-
-#endif
