@@ -86,7 +86,7 @@ namespace csound
    * <li>s = pitch-class set as Mason number</li>
    * </ol>
    */
-  class Lindenmayer :
+  class SILENCE_PUBLIC Lindenmayer :
     public ScoreNode
   {
   protected:
