@@ -43,19 +43,14 @@ namespace csound
    * A ScoreModel that uses Csound to render generated scores,
    * via the CppSound class.
    */
-  class MusicModel :
+  class SILENCE_PUBLIC MusicModel :
     public ScoreModel
   {
   public:
     MusicModel();
     virtual ~MusicModel();
     virtual void initialize();
-    virtual void generate();
-    virtual std::string getFilename() const;
-    virtual void setFilename(std::string filename);
-    static std::string generateFilename();
-    virtual std::string getMidiFilename();
-    virtual std::string getOutputSoundfileName();
+    virtual int generate();
     virtual long getThis();
     virtual Node *getThisNode();
     /**
@@ -70,11 +65,12 @@ namespace csound
      * appends optional text to it,
      * invokes generate(), invokes createCsoundScore(), and invokes perform().
      */
-    virtual void render();
+    virtual int render();
+    virtual void stop();
     /**
      * Uses csound to perform the current score.
      */
-    virtual void perform();
+    virtual int perform();
     /**
      * Clear all contents of this.
      */
@@ -162,6 +158,22 @@ namespace csound
      * (convenience wrapper for CppSound::getCommand()).
      */
     virtual std::string getCsoundCommand() const;
+    /**
+     * Pass the invoking program's command-line arguments to processArgs()
+     * and it will perform the following commands:
+     *
+     * --csound        Render generated score using set Csound orchestra.
+     * --midi          Render generated score as MIDI file and play it (default).
+     * --pianoteq      Play generated MIDI sequence file with Pianoteq.
+     * --pianoteq-wav  Render score to soundfile using Pianoteq,
+     *                 post-process it, and play it.
+     * --playmidi      Play generated MIDI filev
+     *                 post-process it, and play it.
+     * --playwav       Play rendered or normalized output soundfile.
+     * --post          Post-process Csound output soundfile:
+     *                 normalize, CD, MP3, tag, and play it.
+     */
+    virtual int processArgs(const std::vector<std::string> &args);
   protected:
     /**
      * Self-contained Csound object.
