@@ -45,7 +45,7 @@ namespace csound
    * Nodes can transform silence::Events produced by child nodes.
    * Nodes can produce silence::Events.
    */
-  class Node
+  class SILENCE_PUBLIC Node
   {
   protected:
     ublas::matrix<double> localCoordinates;
@@ -69,8 +69,8 @@ namespace csound
                                            Score &score);
     /**
      * The default implementation does nothing.
-     * Derived nodes that produce notes from scratch should 
-     * transform them using the composite transformation of 
+     * Derived nodes that produce notes from scratch should
+     * transform them using the composite transformation of
      * coordinate system, which is passed in from the traverse() function.
      */
     virtual void produceOrTransform(Score &score,
@@ -84,19 +84,18 @@ namespace csound
     virtual void addChild(Node *node);
   };
   typedef Node* NodePtr;
-  
+
   /**
    * Removes all duplicate events produced by the child nodes of this.
    */
-  class RemoveDuplicates : public Node
+  class SILENCE_PUBLIC RemoveDuplicates : public Node
   {
     public:
     virtual void produceOrTransform(Score &score,
                                     size_t beginAt,
                                     size_t endAt,
                                     const ublas::matrix<double> &compositeCordinates);
-        
+
   };
 }
 #endif
-
