@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #include "CppSound.hpp"
-#include "Midifile.hpp"
+// #include "Midifile.hpp"
 #include "Score.hpp"
 #include "System.hpp"
 #include "Conversions.hpp"
@@ -32,6 +32,8 @@
 #include <fstream>
 #include <sstream>
 
+#include <allegro.h>
+
 #if defined(HAVE_MUSICXML2)
 #if defined(EXP)
 #undef EXP
@@ -50,7 +52,7 @@ using namespace MusicXML2;
 namespace csound
 {
 
-void printChord(std::ostream &stream, std::string label, const std::vector<double> &chord)
+void SILENCE_PUBLIC printChord(std::ostream &stream, std::string label, const std::vector<double> &chord)
 {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
         return;
@@ -65,7 +67,7 @@ void printChord(std::ostream &stream, std::string label, const std::vector<doubl
     stream << "]" << std::endl;
 }
 
-void printChord(std::string label, const std::vector<double> &chord)
+void SILENCE_PUBLIC printChord(std::string label, const std::vector<double> &chord)
 {
     if (!( (System::getMessageLevel() & System::INFORMATION_LEVEL) == System::INFORMATION_LEVEL) ) {
         return;
@@ -172,9 +174,25 @@ void Score::load(std::string filename)
 
 void Score::load(std::istream &stream)
 {
-    MidiFile midiFile;
-    midiFile.read(stream);
-    load(midiFile);
+  Alg_seq seq(stream, true);
+  seq.convert_to_seconds();
+  Alg_iterator iterator(&seq, false);
+  iterator.begin();
+  for(;;) {
+    Alg_event *event = iterator.next();
+    if (!event) {
+      break;
+    }
+    append(event->get_start_time(),
+	   event->get_duration(),
+	   double(144),
+	   double(event->chan),
+	   event->get_pitch(),
+	   event->get_loud());	     
+  }
+  // MidiFile midiFile;
+  // midiFile.read(stream);
+  // load(midiFile);
 }
 
 #if defined(HAVE_MUSICXML2)
@@ -225,7 +243,7 @@ static Sxmlelement makeAttributes()
 
 static std::string makePartId(int partid)
 {
-
+    return "";
 }
 
 static Sxmlelement makePart(int instrument, const std::vector<const Event *> &part_)
@@ -299,7 +317,7 @@ void Score::save(std::string filename)
     System::inform("BEGAN Score::save(%s)...\n", filename.c_str());
     std::ofstream stream;
     //stream.open(filename.c_str(), std::ios_base::binary);
-    stream.open(filename.c_str(), std::ifstream::binary);
+    stream.open(filename.c_str(), std::ios::out | std::ios::binary);
     if (filename.find(".mid") != std::string::npos ||
             filename.find(".MID") != std::string::npos) {
         save(stream);
@@ -333,8 +351,32 @@ void Score::save(std::string filename)
 
 void Score::save(std::ostream &stream)
 {
-    save(midifile);
-    midifile.write(stream);
+    Alg_seq seq;
+    for (size_t i = 0, n = size(); i < n; ++i) {
+      const Event &event = at(i);
+      if (event.isNoteOn()) {
+	int channel = event.getChannel();
+	double time = event.getTime();
+	double duration = event.getDuration();
+	float pitch = event.getKey();
+	float loudness = event.getVelocity();
+	int identifier = i;
+	Alg_note *note = seq.create_note(time, 
+					 channel,  
+					 pitch, 
+					 pitch, 
+					 loudness,  
+					 duration);
+	// Does nothing if the track already exists.
+	seq.add_track(channel);
+	seq.add_event(note, channel);
+      }
+    }
+    // Write with time in seconds.
+    seq.write(std::cout, true);
+    seq.smf_write(stream);
+  // save(midifile);
+  // midifile.write(stream);
 }
 
 static double max(double a, double b)
@@ -470,7 +512,7 @@ void Score::rescale(Event &event)
         }
     }
 }
-
+/*
 void Score::load(MidiFile &midiFile)
 {
     std::vector<Event>::clear();
@@ -504,7 +546,9 @@ void Score::load(MidiFile &midiFile)
     findScale();
     sort();
 }
+*/
 
+/*
 void Score::save(MidiFile &midiFile)
 {
     findScale();
@@ -555,6 +599,7 @@ void Score::save(MidiFile &midiFile)
     }
     midiFile.midiHeader.trackCount = midiFile.midiTracks.size();
 }
+  */
 
 void Score::dump(std::ostream &stream)
 {
@@ -1279,4 +1324,38 @@ void Score::remove(size_t index)
 {
     erase(begin() + index);
 }
+void Score::tieOverlappingNotes(bool considerInstrumentNumber)
+{
+    sort();
+    for (int laterI = size() - 1; laterI > 1; --laterI) {
+        Event &laterEvent = (*this)[laterI];
+        for (int earlierI = laterI - 1; earlierI > 0; --earlierI) {
+            Event &earlierEvent = (*this)[earlierI];
+            if (earlierEvent.getKeyNumber() != laterEvent.getKeyNumber()) {
+              continue;
+            }
+            if (earlierEvent.getVelocity() <= 0.0 || laterEvent.getVelocity() <= 0.0) {
+              continue;
+            }
+            if (earlierEvent.getOffTime() < laterEvent.getTime()) {
+              continue;
+            }
+            if (considerInstrumentNumber && (earlierEvent.getChannel() != laterEvent.getChannel())) {
+                continue;
+            }
+            // Ok, must be tied.
+            earlierEvent.setOffTime(laterEvent.getOffTime());
+            erase(begin() + laterI);
+            break;
+        }
+    }
 }
+
+void Score::temper(double tonesPerOctave)
+{
+    for (size_t i = 0, n = size(); i < n; ++i) {
+        (*this)[i].temper(tonesPerOctave);
+    }
+}
+}
+
