@@ -28,9 +28,9 @@
 
 namespace csound
 {
-  extern void printChord(std::ostream &stream, std::string label, const std::vector<double> &chord);
+  extern void SILENCE_PUBLIC printChord(std::ostream &stream, std::string label, const std::vector<double> &chord);
 
-  extern void printChord(std::string label, const std::vector<double> &chord);
+  extern void SILENCE_PUBLIC printChord(std::string label, const std::vector<double> &chord);
 
   /**
    * Utility class for storing voice-leading operations.
@@ -38,11 +38,12 @@ namespace csound
   VoiceleadingOperation::VoiceleadingOperation() :
     beginTime(0.0),
     rescaledBeginTime(0.0),
-    endTime(0.0),
     rescaledEndTime(0.0),
     P(DBL_MAX),
     T(DBL_MAX),
     C(DBL_MAX),
+    K(DBL_MAX),
+    Q(DBL_MAX),
     V(DBL_MAX),
     L(false),
     begin(0),
@@ -71,7 +72,6 @@ namespace csound
   std::ostream &operator << (std::ostream &stream, const VoiceleadingOperation &operation)
   {
     stream << "  beginTime:         " << operation.beginTime << std::endl;
-    stream << "  endTime:           " << operation.endTime << std::endl;
     stream << "  rescaledBeginTime: " << operation.rescaledBeginTime << std::endl;
     stream << "  rescaledEndTime:   " << operation.rescaledEndTime << std::endl;
     stream << "  begin:             " << operation.begin << std::endl;
@@ -85,6 +85,12 @@ namespace csound
     if (!(operation.C == DBL_MAX)) {
       stream << "  C:                 " << operation.C << std::endl;
     }
+    if (!(operation.K == DBL_MAX)) {
+      stream << "  K:                 " << operation.K << std::endl;
+    }
+    if (!(operation.Q == DBL_MAX)) {
+      stream << "  Q:                 " << operation.Q << std::endl;
+    }
     if (!(operation.V == DBL_MAX)) {
       stream << "  V:                 " << operation.V << std::endl;
     }
@@ -104,14 +110,73 @@ namespace csound
       stream << "Events in operation: " << (operation.end - operation.begin) << std::endl;
       stream << "priorOperation:      " << std::endl << priorOperation;
       stream << "currrentOperation:   " << std::endl << operation;
+      stream << "modality:            ";
+      printChord(stream, "", modality);
       stream << std::endl;
       System::inform(stream.str().c_str());
     }
     if (operation.begin == operation.end) {
       return;
     }
-    if (!(operation.P == DBL_MAX) && !(operation.T == DBL_MAX)) {
+    if (!(operation.K == DBL_MAX)) {
+      if ((operation.V == DBL_MAX) && (!operation.L)) {
+        System::inform("Operation: K\n");
+        score.setK(priorOperation.begin,
+                   operation.begin,
+                   operation.end,
+                   base,
+                   range);
+      } else if ((operation.V != DBL_MAX) && (!operation.L)) {
+        System::inform("Operation: KV\n");
+        score.setKV(priorOperation.begin,
+                    operation.begin,
+                    operation.end,
+                    operation.V,
+                    base,
+                    range);
+      } else if ((operation.V == DBL_MAX) && (operation.L)) {
+        System::inform("Operation: KL\n");
+        score.setKL(priorOperation.begin,
+                    operation.begin,
+                    operation.end,
+                    base,
+                    range,
+                    operation.avoidParallels);
+      }
+    } else if (!(operation.Q == DBL_MAX)) {
+      if ((operation.V == DBL_MAX) && (!operation.L)) {
+        System::inform("Operation: Q\n");
+        score.setQ(priorOperation.begin,
+                   operation.begin,
+                   operation.end,
+                   operation.Q,
+                   modality,
+                   base,
+                   range);
+      } else if ((operation.V != DBL_MAX) && (!operation.L)) {
+        System::inform("Operation: QV\n");
+        score.setQV(priorOperation.begin,
+                    operation.begin,
+                    operation.end,
+                    operation.Q,
+                    modality,
+                    operation.V,
+                    base,
+                    range);
+      } else if ((operation.V == DBL_MAX) && (operation.L)) {
+        System::inform("Operation: QL\n");
+        score.setQL(priorOperation.begin,
+                    operation.begin,
+                    operation.end,
+                    operation.Q,
+                    modality,
+                    base,
+                    range,
+                    operation.avoidParallels);
+      }
+    } else if (!(operation.P == DBL_MAX) && !(operation.T == DBL_MAX)) {
       if (!(operation.V == DBL_MAX)) {
+        System::inform("Operation: PTV\n");
         score.setPTV(operation.begin,
                      operation.end,
                      operation.P,
@@ -120,6 +185,7 @@ namespace csound
                      base,
                      range);
       } else if (operation.L) {
+        System::inform("Operation: PTL\n");
         score.setPT(operation.begin,
                     operation.end,
                     operation.P,
@@ -136,6 +202,7 @@ namespace csound
                         avoidParallels,
                         divisionsPerOctave);
       } else {
+        System::inform("Operation: PT\n");
         score.setPT(operation.begin,
                     operation.end,
                     operation.P,
@@ -146,6 +213,7 @@ namespace csound
       }
     } else if (!(operation.C == DBL_MAX)) {
       if (!(operation.V == DBL_MAX)) {
+        System::inform("Operation: CV\n");
         std::vector<double> pcs = Voicelead::mToPitchClassSet(Voicelead::cToM(operation.C, divisionsPerOctave), divisionsPerOctave);
         printChord("CV", pcs);
         std::vector<double> pt = Voicelead::pitchClassSetToPandT(pcs, divisionsPerOctave);
@@ -160,6 +228,7 @@ namespace csound
                      base,
                      range);
       } else if (operation.L) {
+        System::inform("Operation: CL\n");
         std::vector<double> pcs = Voicelead::mToPitchClassSet(Voicelead::cToM(operation.C, divisionsPerOctave), divisionsPerOctave);
         printChord("CL", pcs);
         score.voicelead(priorOperation.begin,
@@ -172,6 +241,7 @@ namespace csound
                         avoidParallels,
                         divisionsPerOctave);
       } else {
+        System::inform("Operation: C\n");
         std::vector<double> pcs = Voicelead::mToPitchClassSet(Voicelead::cToM(operation.C, divisionsPerOctave), divisionsPerOctave);
         score.setPitchClassSet(operation.begin,
                                operation.end,
@@ -179,6 +249,7 @@ namespace csound
                                divisionsPerOctave);
       }
     } else {
+        System::inform("Operation: V\n");
         if (!(operation.V == DBL_MAX)) {
         std::vector<double> ptv = score.getPTV(operation.begin,
                                                operation.end,
@@ -194,6 +265,7 @@ namespace csound
                      range,
                      divisionsPerOctave);
       } else if (operation.L) {
+        System::inform("Operation: L\n");
         score.voicelead(priorOperation.begin,
                         priorOperation.end,
                         operation.begin,
@@ -267,6 +339,48 @@ namespace csound
     CL(time, Voicelead::nameToC(C, divisionsPerOctave), avoidParallels);
   }
 
+  void VoiceleadingNode::K(double time)
+  {
+    operations[time].beginTime = time;
+    operations[time].K = 1.0;
+  }
+
+  void VoiceleadingNode::KV(double time, double V)
+  {
+    operations[time].beginTime = time;
+    operations[time].K = 1.0;
+    operations[time].V = V;
+  }
+
+  void VoiceleadingNode::KL(double time, bool avoidParallels)
+  {
+    operations[time].beginTime = time;
+    operations[time].K = 1.0;
+    operations[time].L = true;
+    operations[time].avoidParallels = avoidParallels;
+  }
+
+  void VoiceleadingNode::Q(double time, double Q)
+  {
+    operations[time].beginTime = time;
+    operations[time].Q = Q;
+  }
+
+  void VoiceleadingNode::QV(double time, double Q, double V)
+  {
+    operations[time].beginTime = time;
+    operations[time].Q = Q;
+    operations[time].V = V;
+  }
+
+  void VoiceleadingNode::QL(double time, double Q, bool avoidParallels)
+  {
+    operations[time].beginTime = time;
+    operations[time].Q = Q;
+    operations[time].L = true;
+    operations[time].avoidParallels = avoidParallels;
+  }
+
   void VoiceleadingNode::V(double time, double V_)
   {
     operations[time].beginTime = time;
@@ -280,9 +394,18 @@ namespace csound
     operations[time].avoidParallels = avoidParallels;
   }
 
-  void VoiceleadingNode::produceOrTransform(Score &score, size_t beginAt, size_t endAt, const ublas::matrix<double> &coordinates)
+  void VoiceleadingNode::produceOrTransform(Score &score,
+                                            size_t beginAt,
+                                            size_t endAt,
+                                            const ublas::matrix<double> &compositeCoordinates)
   {
     transform(score, rescaleTimes);
+    // Apply the global transformation of coordinate system
+    // to all child events produced by this node.
+    size_t finalEndAt = score.size();
+    for (size_t i = endAt; i < finalEndAt; i++) {
+      score[i] = ublas::prod(compositeCoordinates, score[i]);
+    }
   }
 
   void VoiceleadingNode::transform(Score &score, bool rescaleTimes_)
@@ -293,9 +416,9 @@ namespace csound
     // Find the time rescale factor.
     score.sort();
     score.findScale();
-    double origin = score.scaleActualMinima.getTime();
-    double duration = score.getDuration();
-    double scoreMaxTime = origin + duration;
+    double scoreMinTime = score.scaleActualMinima.getTime();
+    double scoreDuration = score.getDuration();
+    double scoreMaxTime = scoreMinTime + scoreDuration;
     double operationMaxTime = 0.0;
     double timeScale = 1.0;
     std::vector<VoiceleadingOperation *> ops;
@@ -305,45 +428,56 @@ namespace csound
       }
       ops.push_back(&it->second);
     }
+
     if (rescaleTimes_) {
       if (operationMaxTime > 0.0) {
-        timeScale = duration / operationMaxTime;
+        timeScale = scoreMaxTime / operationMaxTime;
       }
     }
     System::inform("BEGAN VoiceleadingNode::produceOrTransform  operationMaxTime: %f  origin: %f  duration: %f  scoreMaxTime: %f  timeScale: %f...\n",
                    operationMaxTime,
-                   origin,
-                   duration,
+                   scoreMinTime,
+                   scoreDuration,
                    scoreMaxTime,
                    timeScale);
     VoiceleadingOperation *priorOperation = 0;
     VoiceleadingOperation *currentOperation = 0;
     VoiceleadingOperation *nextOperation = 0;
-    for (int priorIndex = -1, currentIndex = 0, nextIndex = 1, firstIndex = 0, endIndex = ops.size(), backIndex = ops.size() - 1;
-         currentIndex < endIndex;
-         priorIndex++, currentIndex++, nextIndex++) {
-      if (currentIndex <= firstIndex) {
-        priorOperation = ops[currentIndex];
-        currentOperation = ops[currentIndex];
+    int priorIndex = 0;
+    int currentIndex = 0;
+    int nextIndex = 0;
+    int backIndex = ops.size() - 1;
+    int endIndex = ops.size();
+    for (currentIndex = 0; currentIndex < endIndex; ++currentIndex) {
+      if (currentIndex == 0) {
+        priorIndex = currentIndex;
       } else {
-        priorOperation = ops[priorIndex];
-        currentOperation = ops[currentIndex];
+        priorIndex = currentIndex - 1;
       }
-      currentOperation->rescaledBeginTime = ((currentOperation->beginTime - origin) * timeScale) + origin;
+      if (currentIndex == backIndex) {
+        nextIndex = currentIndex;
+      } else {
+        nextIndex = currentIndex + 1;
+      }
+      priorOperation = ops[priorIndex];
+      currentOperation = ops[currentIndex];
+      nextOperation = ops[nextIndex];
+      currentOperation->rescaledBeginTime = currentOperation->beginTime * timeScale;
       currentOperation->begin = score.indexAtTime(currentOperation->rescaledBeginTime);
-      if (currentIndex >= backIndex) {
-        currentOperation->endTime = std::max(currentOperation->rescaledBeginTime, scoreMaxTime);
-        currentOperation->rescaledEndTime = currentOperation->endTime;
-        currentOperation->end = score.size();
-      } else {
-        nextOperation = ops[nextIndex];
-        currentOperation->endTime = nextOperation->beginTime;
-        currentOperation->rescaledEndTime = currentOperation->endTime * timeScale;
-        currentOperation->end = score.indexAfterTime(currentOperation->rescaledEndTime);
-      }
+      currentOperation->rescaledEndTime = nextOperation->beginTime * timeScale;
+      currentOperation->end = score.indexAfterTime(currentOperation->rescaledEndTime);
       apply(score, *priorOperation, *currentOperation);
     }
     System::inform("ENDED VoiceleadingNode::produceOrTransform.\n");
   }
 
+  void VoiceleadingNode::setModality(const std::vector<double> &pcs)
+  {
+    modality = pcs;
+  }
+
+  std::vector<double> VoiceleadingNode::getModality() const
+  {
+    return modality;
+  }
 }
