@@ -98,7 +98,7 @@ typedef float mus_sample_t;
 #if defined(LINUX) || defined(MACOSX)
 #  define ATSA_RES_FILE "/tmp/atsa_res.wav"
 #else
-#  define ATSA_RES_FILE "atsa_res.wav"
+#  define ATSA_RES_FILE "/atsa_res.wav"
 #endif
 
 /* constants and macros */
@@ -534,7 +534,7 @@ static int main_anal(CSOUND *csound, char *soundfile, char *ats_outfile,
     fd = csound->FileOpen2(csound, &outfile, CSFILE_STD, ats_outfile, "wb",
                           NULL, CSFTYPE_ATS, 0);
     if (fd == NULL) {
-      csound->Die(csound, Str("\n Could not open %s for writing, bye...\n"),
+      csound->Die(csound, Str("\nCould not open %s for writing, bye...\n"),
                   ats_outfile);
     }
     /* call tracker */
@@ -721,7 +721,17 @@ static int atsa_main(CSOUND *csound, int argc, char **argv)
         soundfile == NULL || soundfile[0] == '\0' ||
         ats_outfile == NULL || ats_outfile[0] == '\0')
       usage(csound);
+#ifdef WIN32
+    {
+      char buffer[160];
+      char * tmp = getenv("TEMP");
+      strncpy(buffer, tmp, 160);
+      strncat(buffer, ATSA_RES_FILE, 160);
+      val = main_anal(csound, soundfile, ats_outfile, anargs, buffer);
+    }
+#else
     val = main_anal(csound, soundfile, ats_outfile, anargs, ATSA_RES_FILE);
+#endif
     csound->Free(csound, anargs);
     return (val);
 }
@@ -1932,11 +1942,13 @@ static void ats_save(CSOUND *csound, ATS_SOUND *sound, FILE *outfile,
     header.typ = (double) type;
     /* write header */
     fseek(outfile, 0, SEEK_SET);
-    fwrite(&header, 1, sizeof(ATS_HEADER), outfile);
+    if (UNLIKELY(1!=fwrite(&header, 1, sizeof(ATS_HEADER), outfile)))
+      fprintf(stderr, Str("Write failure\n"));
     /* write frame data */
     for (frm = 0; frm < sound->frames; frm++) {
       daux = sound->time[0][frm];
-      fwrite(&daux, 1, sizeof(double), outfile);
+      if (UNLIKELY(1!=fwrite(&daux, 1, sizeof(double), outfile)))
+        fprintf(stderr, Str("Write failure\n"));
       for (i = 0; i < sound->partials; i++) {
         /* we ouput data in increasing frequency order
          * and we check for dead partials
@@ -1946,12 +1958,15 @@ static void ats_save(CSOUND *csound, ATS_SOUND *sound, FILE *outfile,
           par = sound->av[i].track;
           /* output data to file */
           daux = sound->amp[par][frm];
-          fwrite(&daux, 1, sizeof(double), outfile);
+          if (UNLIKELY(1!=fwrite(&daux, 1, sizeof(double), outfile)))
+            fprintf(stderr, Str("Write failure\n"));
           daux = sound->frq[par][frm];
-          fwrite(&daux, 1, sizeof(double), outfile);
+          if (UNLIKELY(1!=fwrite(&daux, 1, sizeof(double), outfile)))
+            fprintf(stderr, Str("Write failure\n"));
           if (type == 2 || type == 4) {
             daux = sound->pha[par][frm];
-            fwrite(&daux, 1, sizeof(double), outfile);
+            if (UNLIKELY(1!=fwrite(&daux, 1, sizeof(double), outfile)))
+              fprintf(stderr, Str("Write failure\n"));
           }
         }
       }
@@ -1959,7 +1974,8 @@ static void ats_save(CSOUND *csound, ATS_SOUND *sound, FILE *outfile,
       if (type == 3 || type == 4) {
         for (i = 0; i < ATSA_CRITICAL_BANDS; i++) {
           daux = sound->band_energy[i][frm];
-          fwrite(&daux, 1, sizeof(double), outfile);
+          if (UNLIKELY(1!=fwrite(&daux, 1, sizeof(double), outfile)))
+            fprintf(stderr, Str("Write failure\n"));
         }
       }
     }
@@ -2144,7 +2160,7 @@ static ATS_SOUND *tracker(CSOUND *csound, ANARGS *anargs, char *soundfile,
       i_tmp =
           (ATSA_MGAPLEN < anargs->frames) ? ATSA_MGAPLEN : anargs->frames - 1;
       csound->Warning(csound,
-                      Str("min. gap length %d out of bounds, " "forced to: %d"),
+                      Str("min. gap length %d out of bounds, forced to: %d"),
                       anargs->min_gap_len, i_tmp);
       anargs->min_gap_len = i_tmp;
     }
@@ -2363,8 +2379,17 @@ static ATS_SOUND *tracker(CSOUND *csound, ANARGS *anargs, char *soundfile,
     csound->Free(csound, bufs);
     /* analyse residual */
     if (anargs->type == 3 || anargs->type == 4) {
+#ifdef WIN32
+      char buffer[160];
+      char * tmp = getenv("TEMP");
+      strncpy(buffer, tmp, 160);
+      strncat(buffer, ATSA_RES_FILE, 160);
+      csound->Message(csound, Str("Analysing residual..."));
+      residual_analysis(csound, buffer, sound);
+#else
       csound->Message(csound, Str("Analysing residual..."));
       residual_analysis(csound, ATSA_RES_FILE, sound);
+#endif
       csound->Message(csound, Str("done!\n"));
     }
     csound->Message(csound, Str("tracking completed.\n"));
