@@ -205,7 +205,6 @@ static int srconv(CSOUND *csound, int argc, char **argv)
 
     FILE        *tvfp = NULL;   /* time-vary function file */
     SOUNDIN     *p;
-    void        *dummy;
     int         channel = ALLCHNLS;
     MYFLT       beg_time = FL(0.0), input_dur = FL(0.0), sr = FL(0.0);
     char        *infile = NULL, *bfile = NULL;
@@ -374,17 +373,18 @@ static int srconv(CSOUND *csound, int argc, char **argv)
         goto err_rtn_msg;
       }
       /* register file to be closed by csoundReset() */
-      dummy = csound->CreateFileHandle(csound, &tvfp, CSFILE_STD, bfile);
-      fscanf(tvfp, "%d", &tvlen);
+      (void) csound->CreateFileHandle(csound, &tvfp, CSFILE_STD, bfile);
+      if (UNLIKELY(fscanf(tvfp, "%d", &tvlen) != 1))
+          csound->Message(csound, Str("Read failure\n"));
       fxval = (MYFLT*) csound->Malloc(csound, tvlen * sizeof(MYFLT));
       fyval = (MYFLT*) csound->Malloc(csound, tvlen * sizeof(MYFLT));
       i0 = fxval;
       i1 = fyval;
       for (i = 0; i < tvlen; i++, i0++, i1++) {
 #ifdef USE_DOUBLE
-        if ((fscanf(tvfp, "%lf %lf", i0, i1)) == EOF) {
+        if ((fscanf(tvfp, "%lf %lf", i0, i1)) != 2) {
 #else
-        if ((fscanf(tvfp, "%f %f", i0, i1)) == EOF) {
+        if ((fscanf(tvfp, "%f %f", i0, i1)) != 2) {
 #endif
           sprintf(err_msg, Str("srconv: too few x-y pairs "
                                "in time-vary function file"));
@@ -474,8 +474,8 @@ static int srconv(CSOUND *csound, int argc, char **argv)
         goto err_rtn_msg;
       }
       /* register file to be closed by csoundReset() */
-      dummy = csound->CreateFileHandle(csound, &outfd, CSFILE_SND_W,
-                                               O->outfilename);
+      (void) csound->CreateFileHandle(csound, &outfd, CSFILE_SND_W,
+                                      O->outfilename);
       sf_command(outfd, SFC_SET_CLIPPING, NULL, SF_TRUE);
     }
     csound->esr = (MYFLT) p->sr;
